*************************************************************
*Este programa debe ser utilizado con el software SPSS versin 
15 o superior. 

*Todas las bases de datos del Mdulo de Condiciones
Socioeconmicas pueden ser obtenidas en la pgina de 
Internet del CONEVAL www.coneval.gob.mx o del INEGI, 
www.inegi.org.mx, y deben estar convertidas a formato  *.sav. 

*En este programa se utilizan las siguientes bases, renombrndolas
de la siguiente forma:
Base hogares: hogares.sav
Base poblacin: poblacion.sav
Base de ingresos: ingresos.sav
Base de concentrado: concentrado.sav
Base de trabajos: trabajos.sav
Bases de no monetario: nomonetarioe.sav, nomonetariom.sav

*En este programa se utilizan tres tipos de archivos, los 
cuales estn ubicados en las siguientes carpetas:
*
1) Bases originales: "C:\Medicion\2010\SPSS\MCS"
2) Bases generadas: "C:\Medicion\2010\SPSS\Bases"
3) Bitcoras: "C:\Medicion\2010\SPSS\Log"

************************************************************************************
*
*	PROGRAMA PARA LA MEDICIN DE LA POBREZA 2010
*
************************************************************************************

*De acuerdo a la metodologa para la medicin 
de la pobreza establecida por el CONEVAL, la medicin de la 
pobreza se realiza en tres espacios: el espacio del bienestar 
econmico (ingreso), el espacio de derechos sociales (privacin
social) y el contexto territorial (cohesin social).

*En este programa se construyen bases independientes para cada
una de las dimensiones a considerar (rezago educativo, acceso a 
la salud, calidad y espacios de la vivienda, servicios bsicos en la 
vivienda, acceso a la seguridad social, acceso a la alimentacin,
ingreso y cohesin social), y al final se integran en un solo archivo
para efectuar la medicin.

********************************************************************************
* Parte I Indicadores de Privacin Social:
*
*INDICADOR DE CARENCIA POR REZAGO EDUCATIVO
*
********************************************************************************.

GET
  FILE='C:\Medicion\2010\SPSS\MCS\poblacion.sav'.

* Poblacin objeto: no se incluye a huspedes ni trabajadores domsticos.

SELECT IF  ~("400"<=parentesco & parentesco<"500"). 
SELECT IF  ~("700"<=parentesco & parentesco<"800"). 

*Para la construccin del indicador de carencia por rezago
educativo, se utilizan las variables de edad, ao de nacimiento,
asistencia a la escuela y nivel educativo.

* EDAD*.

VARIABLE LABELS edad "Edad reportada al momento de la entrevista".

* AO DE NACIMIENTO*.

COMPUTE anio_med=2010.

COMPUTE 		anac_e=anio_med-edad.
IF SYSMISS(edad)	anac_e=9.
RECODE anac_e (9=SYSMISS).
VARIABLE LABELS  anac_e "Ao de nacimiento".
FORMATS anac_e(F1).

* INASISTENCIA A LA ESCUELA (se reporta para personas de 3 aos y ms)*.

COMPUTE             inas_esc=-1.
IF asis_esc="1"        inas_esc=0.
IF asis_esc="2"        inas_esc=1.
IF edad<3              inas_esc=99.
RECODE inas_esc(99=SYSMIS).
VARIABLE LABELS inas_esc "Inasistencia a la escuela".
VALUE LABELS inas_esc   0 "S asiste"
                                        1 "No asiste".
FORMATS inas_esc (F1).

* NIVEL EDUCATIVO (se reporta para personas de 3 aos o ms).

***********************************************************************
*
La variable de nivel educativo contiene tres categoras:
*
1. Poblacin que no asisti a la escuela, o cuyo mximo nivel de estudios 
es preescolar o 5o. grado de primaria.
*
2. Poblacin cuyo mximo nivel educativo es 6o. grado de primaria; 1er o 2o
grado de secundaria; 1er. o 2o. grado de carrera tcnica o comercial con 
antecedente de primaria; o, 1er. o 2o. grado de normal con antecedente de primaria.
*
3. Poblacin cuyo mximo nivel de estudios es 3er. grado de secundaria; 
3er. grado de carrera tcnica o comercial con antecedente primaria; carrera 
tcnica o comercial con antecedente de secundaria o preparatoria; 3er. grado 
de normal con antecedente de primaria; normal con antecedente de 
secundaria o preparatoria; preparatoria o bachillerato; profesional; maestra
o doctorado. 
*
**********************************************************************.
COMPUTE nivelaprob2=NUMBER(nivelaprob,F1).
COMPUTE gradoaprob2=NUMBER(gradoaprob,F1).
COMPUTE antec_esc2=NUMBER(antec_esc,F1).

COMPUTE										niv_ed=-1.
IF (nivelaprob2<2) |  ((nivelaprob2=2)  & (gradoaprob2<6 ))					niv_ed=0.

IF (nivelaprob2=2) & (gradoaprob2=6 ) |             
		     (nivelaprob2=3)  & (0<=gradoaprob2  & gradoaprob2<3) |
		     (nivelaprob2=5 | nivelaprob2=6) & gradoaprob2<3 & antec_esc2=1        	niv_ed=1.

IF (nivelaprob2=3)  & gradoaprob2=3  |
		     (nivelaprob2=4) |
		     (nivelaprob2=5 | nivelaprob2=6) & antec_esc2=1   &  gradoaprob2>=3 |
		     (nivelaprob2=5 | nivelaprob2=6) & antec_esc2>1 |
		     (7<=nivelaprob2 & nivelaprob2<10)                       			niv_ed=2.
IF edad<=2                                                                                   			niv_ed=99.
VARIABLE LABELS niv_ed "Nivel educativo".
VALUE LABELS  niv_ed	0 "Primaria incompleta o menos"
                                    1 "Primaria completa o secundaria incompleta"
                                    2 "Secundaria completa o mayor nivel educativo".
RECODE niv_ed (-1 99=sysmiss).
FORMATS niv_ed (F1).



***********************************************************************************************************
*
*		INDICADOR DE CARENCIA POR REZAGO EDUCATIVO
*
********************************************************************************************************** .
*
Se considera en situacin de carencia por rezago educativo
a la poblacin que cumpla con alguno de los siguientes criterios:
*
1. Se encuentra entre los 3 y los 15 aos y no ha terminado la educacin
obligatoria (secundaria terminada) o no asiste a la escuela
2. Tiene una edad de 16 aos o ms, su ao de nacimiento aproximado es 1981
o anterior, y no dispone de primaria completa
3. Tiene una edad de 16 aos o ms, su ao de nacimiento aproximado es 1982
en adelante, y no dispone de primaria secundaria completa
*
No se considera en situacin de carencia por rezago educativo
a la poblacin que cumpla con alguno de los siguientes criterios:
*
1. Tiene una edad menor a la requerida para estar inscrito en el
sistema educativo nacional
2. Se encuentra entre los 3 y 15 aos y asiste a un centro de
educacin formal
3. Se encuentra entre los 3 y 15 aos y dispone de la educacin obligatoria
(secundaria terminada)
4. Tiene una edad de 16 aos o ms, su ao de nacimiento aproximado es 1981
o anterior, y dispone de educacin primaria completa o un mayor nivel educativo
5. Tiene una edad de 16 aos o ms, su ao de nacimiento aproximado es 1982
en adelante, y dispone de educacin secundaria completa o un mayor nivel educativo
*
***********************************************************************.

COMPUTE                                                              		ic_rezedu=-1.
IF (3<=edad & edad<16) & inas_esc=1 & (niv_ed=0 | niv_ed=1)     ic_rezedu=1.
IF (edad>=16) & anac_e<1982 & niv_ed=0                       	ic_rezedu=1.
IF edad>=16 & anac_e>=1982 & (niv_ed=0 | niv_ed=1)                 ic_rezedu=1.
IF (0<=edad & edad<3)                                             		ic_rezedu=0.
IF (3<=edad & edad<16) & inas_esc=0                        		ic_rezedu=0.
IF (3<=edad & edad<16) & inas_esc=1 & niv_ed=2                       ic_rezedu=0.
IF edad>=16 & anac_e>=1982 & niv_ed=2                 		ic_rezedu=0.
IF edad>=16 & anac_e<1982 & (niv_ed=1 | niv_ed=2)                 	ic_rezedu=0.
RECODE ic_rezedu (-1 =SYSMIS).
VARIABLE LABELS  ic_rezedu "Indicador de carencia por rezago educativo".
VALUE LABELS ic_rezedu 0 "No presenta carencia"
                                         1 "Presenta carencia".
FORMATS  ic_rezedu (F1).

SORT CASES proyecto(A) folioviv(A) foliohog(A) numren(A).

*Se salva la base.
SAVE OUTFILE='C:\Medicion\2010\SPSS\Bases\IC_REZEDU10.sav'
 /KEEP =  proyecto folioviv foliohog numren edad anac_e inas_esc niv_ed ic_rezedu
  /COMPRESSED.

*******************************************************************************************
* Parte II Indicadores de Privacin Social:
*
*INDICADOR DE CARENCIA POR ACCESO A LOS SERVICIOS DE SALUD 
*
*******************************************************************************************.

GET
  FILE='C:\Medicion\2010\SPSS\MCS\poblacion.sav'.

* Poblacin objeto: no se incluye a huspedes ni trabajadores domsticos.

SELECT IF  ~("400"<=parentesco & parentesco<"500"). 
SELECT IF  ~("700"<=parentesco & parentesco<"800"). 

*Para la construccin del indicador de carencia por acceso 
a los servicios de salud se utilizan las variables de afiliacin o
inscripcin al seguro popular, afiliacin o inscripcin a una 
institucin de salud.

* SERVICIOS DE SALUD*.
*Se identifica si la poblacin cuenta con Seguro Popular,
servicios mdicos del IMSS, ISSSTE o ISSSTE estatal, PEMEX, 
Defensa o Marina u otros servicios mdicos*.

COMPUTE                                               serv_sal=-1.
IF segpop="1"                                          serv_sal=1.
IF segpop="2" & atemed="1" & inst_1="1"  serv_sal=2. 
IF segpop="2" & atemed="1" & inst_2="2"  serv_sal=3. 
IF segpop="2" & atemed="1" & inst_3="3"  serv_sal=3. 
IF segpop="2" & atemed="1" & inst_4="4"  serv_sal=4. 
IF segpop="2" & atemed="1" & inst_5="5"  serv_sal=5. 
IF segpop="2" & atemed="2"                     serv_sal=0. 
*IF sysmiss(segpop)                                 serv_sal=9.
If segpop=" "                                            serv_sal=9.
VARIABLE LABELS  serv_sal "Servicios de salud".
VALUE LABELS  serv_sal   	0 "No cuenta con servicios mdicos"
				1 "Seguro Popular" 
				2 "IMSS" 
				3 "ISSSTE o ISSSTE estatal" 
				4 "Pemex, Defensa o Marina" 
				5 "Otros".
RECODE serv_sal (9=SYSMISS).
FORMATS serv_sal (F1).

*************************************************************************************
*
*	INDICADOR DE CARENCIA POR ACCESO A LA SALUD
*
*************************************************************************************.
*
Se considera en situacin de carencia por acceso a servicios de salud
a la poblacin que:
*
1. No se encuentra afiliada o inscrita al Seguro Popular o alguna 
institucin que proporcione servicios mdicos
*
No se considera en situacin de carencia por acceso a los servicios 
de salud a la poblacin que:
*
1. Se encuentra afiliada o inscrita al Seguro Popular o alguna
institucin que proporcione servicios mdicos
***********************************************************************.

COMPUTE		ic_asalud=-1.
IF serv_sal=0		ic_asalud=1.
IF serv_sal>=1		ic_asalud=0.
IF SYSMISS(serv_sal)		ic_asalud=9.
VARIABLE LABELS  ic_asalud "Indicador de carencia por acceso a los servicios de salud".
VALUE LABELS  ic_asalud 	0 "No presenta carencia"
				1 "Presenta carencia".
RECODE ic_asalud (9 =SYSMIS).
FORMATS ic_asalud (F1).

SORT CASES proyecto(A) folioviv(A) foliohog(A) numren(A).

*Se salva la base.
SAVE OUTFILE='C:\Medicion\2010\SPSS\Bases\IC_ASALUD10.sav'
 /KEEP =  proyecto folioviv foliohog numren  sexo serv_sal ic_asalud
  /COMPRESSED.


**********************************************************************************************
* Parte III Indicadores de Privacin Social:
*
*INDICADOR DE CARENCIA POR ACCESO A LA SEGURIDAD SOCIAL
*
************************************************************************************************.
*Para la construccin del indicador de esta dimensin se 
requiere de informacin relativa a: condicin laboral, 
prestaciones laborales, parentesco, edad, asistencia a la escuela,
ingresos provenientes de pensiones, entre otras.

*En primer lugar se identifica a la poblacin ocupada y sus
prestaciones, tanto en el trabajo principal como el secundario

*En segundo lugar se analizan los ingresos provenientes
por jubilaciones y pensiones, o por programas de adultos 
mayores

*En tercer lugar se une la informacin de las dos bases
previas a la base de poblacin para la construccin del 
indicador.

************************
*Prestaciones laborales*
************************.

GET
  FILE='C:\Medicion\2010\SPSS\MCS\trabajos.sav'.

*TIPO DE TRABAJADOR:*Identificacin de la poblacin subordinada e independiente.

COMPUTE					 tip_trab=-1.

*Subordinados.
IF subor="1" 					tip_trab=1.

*Independientes que reciben un pago.
IF subor="2" & indep="1" & tiene_suel="1"		tip_trab=2.
IF subor="2" & indep="2" & pago="1"		       	tip_trab=2.


*Independientes que no reciben un pago.
IF subor="2" & indep="1" & tiene_suel="2"		tip_trab=3.
IF subor="2" & indep="2" & (pago="2" | pago="3")	tip_trab=3.
FORMATS tip_trab (F1).

*PRESTACIONES BSICAS POR PARTE DEL TRABAJO
* Prestaciones laborales (incapacidad en caso de enfermedad o 
* maternidad con goce de sueldo y SAR o Afore)

COMPUTE 			inclab=0.
IF pres_1="01"		 	inclab=1.
FORMATS inclab (F1).

COMPUTE 			aforlab=0.
IF pres_8="08"		 	aforlab=1.
FORMATS aforlab (F1).

*OCUPACIN PRINCIPAL Y SECUNDARIA:
*Distincin de prestaciones en trabajo principal y secundario.

COMPUTE numtrab2=NUMBER(numtrab,F1).
FORMATS numtrab2 (F1).

RECODE numtrab2 (1=1)(2=0) INTO ocupa.
FORMATS ocupa (F1).

SORT CASES proyecto(A) folioviv(A) foliohog(A) numren(A).

CASESTOVARS
	/ID=proyecto folioviv foliohog numren
	/INDEX=numtrab2.
EXECUTE.

VARIABLE LABELS tip_trab.1 "Tipo de trabajo 1".
VARIABLE LABELS tip_trab.2 "Tipo de trabajo 2".

RENAME VARIABLES (inclab.1= inclab1).
VARIABLE LABELS  inclab1 "Incapacidad con goce de sueldo en ocupacin principal".
VALUE LABELS inclab1	0 "No cuenta"
                        	1 "S cuenta".
FORMATS inclab1 (F1).

RENAME VARIABLES (inclab.2= inclab2).
VARIABLE LABELS  inclab2 "Incapacidad con goce de sueldo en ocupacin secundaria".
VALUE LABELS inclab2	0 "No cuenta"
                        	1 "S cuenta".
FORMATS inclab2 (F1).

RENAME VARIABLES (aforlab.1= aforlab1).
VARIABLE LABELS aforlab1 "Ocupacin principal: SAR o Afore".
VALUE LABELS aforlab1 	0 "No cuenta"
                                 		1 "S cuenta".
FORMATS aforlab1 (F1).

RENAME VARIABLES (aforlab.2= aforlab2).
VARIABLE LABELS aforlab2 "Ocupacin secundaria: SAR o Afore".
VALUE LABELS aforlab2 	0 "No cuenta"
                                 		1 "S cuenta".
FORMATS aforlab2 (F1).

RECODE ocupa.1 (1=1)(2=0) INTO ocupa1.
VARIABLE LABELS ocupa1 "Ocupacin principal".

RECODE ocupa.2 (0=1)(ELSE=0) INTO ocupa2.
VARIABLE LABELS ocupa2 "Ocupacin secundaria".
VALUE LABELS ocupa2 0 "Sin ocupacin secundaria"
		1 "Con ocupacin secundaria".
FORMATS ocupa2 (F1).

*Identificacin de la poblacin trabajadora (toda la que reporta al menos 
un empleo en la base de trabajos10.sav)*.

COMPUTE trab=1.
VARIABLE LABEL trab "Poblacin con al menos un empleo".

SORT CASES proyecto(A) folioviv(A) foliohog(A) numren(A).

*Se guarda la base con la informacin de los trabajadores.
SAVE OUTFILE='C:\Medicion\2010\SPSS\Bases\prestaciones10.sav'
  /KEEP= proyecto folioviv foliohog numren trab tip_trab.1 inclab1 aforlab1 ocupa1  
 tip_trab.2  inclab2  aforlab2 ocupa2
  /COMPRESSED.

************************
*Ingresos por pensiones*
************************.

GET
  FILE='C:\Medicion\2010\SPSS\MCS\ingresos.sav'.

*Se identifica a la poblacin que:

*- Recibe ingresos por jubilaciones y/o pensiones originadas 
dentro o fuera del pas.

*- Recibe ingresos por programa para adultos mayores.

SELECT IF (clave="P032" | clave="P033" | clave="P044" | clave="P045").

IF (clave="P032" | clave="P033")  ing_pens=MEAN.1(ing_1, ing_2, ing_3, ing_4, ing_5, ing_6).

IF (clave="P044" | clave="P045")  ing_pam=MEAN.1(ing_1, ing_2, ing_3, ing_4, ing_5, ing_6).

VARIABLE LABELS ing_pens "Ingreso promedio mensual por jubilaciones y pensiones".
VARIABLE LABELS ing_pam "Ingreso promedio mensual por programas de adultos mayores".

RECODE ing_pens ing_pam (SYSMISS=0).

AGGREGATE
  /OUTFILE='C:\Medicion\2010\SPSS\Bases\pensiones10.sav'
  /BREAK=proyecto folioviv foliohog numren
  /ing_pens_sum=SUM(ing_pens) 
  /ing_pam_sum=SUM(ing_pam).

****************************
*Construccin del indicador*
****************************.

GET
  FILE='C:\Medicion\2010\SPSS\MCS\poblacion.sav'.

* Poblacin objeto: no se incluye a huspedes ni trabajadores domsticos.

SELECT IF  ~("400"<=parentesco & parentesco<"500"). 
SELECT IF  ~("700"<=parentesco & parentesco<"800"). 

*Integracin de bases.

SORT CASES proyecto(A) folioviv(A) foliohog(A) numren(A).

MATCH FILES /FILE=*
  /TABLE='C:\Medicion\2010\SPSS\Bases\prestaciones10.sav'
  /BY proyecto folioviv foliohog numren.
EXECUTE.

MATCH FILES /FILE=*
  /TABLE='C:\Medicion\2010\SPSS\Bases\pensiones10.sav'
 /RENAME (ing_pens_sum=ing_pens)
 /RENAME (ing_pam_sum=ing_pam)
  /BY proyecto folioviv foliohog numren.
EXECUTE.

*********************************************************************
* PEA (personas de 16 aos o ms)
**********************************************************************.

COMPUTE    							pea=-1.
IF edad>=16   & trab=1 						pea=1.
IF edad>=16   & bustrab_1="1" 					pea=2.
IF edad>=16 & bustrab_1="" & 
(bustrab_2="2" | bustrab_3="3" | bustrab_4="4" | 
bustrab_5="5" |  bustrab_6="6" | bustrab_7="7")	 		pea=0.
IF edad<16  							pea=99.
RECODE pea (-1 99=SYSMIS).
VARIABLE LABELS pea "Poblacin econmicamente activa ".
VALUE LABELS pea	0 "PNEA"
			1 "PEA: ocupada"
			2 "PEA: desocupada".
FORMATS pea (F1).

**********************************************************************
*  TIPO DE TRABAJO
**********************************************************************.
*Se utilizan las variables tip_trab1 y tip_trab2, las cuales se
generan en la base de prestaciones10.dta y se
restringe de acuerdo con la variable pea.

* Ocupacin principal.

RECODE tip_trab.1 (ELSE=COPY) INTO tip_trab1.
COMPUTE 				tipo_trab1=-1.
IF pea=1				tipo_trab1=tip_trab.1.
IF (pea=0 | pea=2)			tipo_trab1=9.
IF SYSMIS (pea)			tipo_trab1=9.
RECODE tipo_trab1 (9=sysmiss).
VARIABLE LABELS tipo_trab1 "Tipo de trabajador en ocupacin principal".
VALUE LABELS  tipo_trab1	1"Depende de un patrn, jefe o sup"
				2 "No depende de un jefe y tiene asignado un sueldo"
				3 "No depende de un jefe y no recibe o tiene asignado un sueldo".
FORMATS tipo_trab1 (F1).

* Ocupacin secundaria.

RECODE tip_trab.2 (ELSE=COPY) INTO tip_trab2.
COMPUTE 				tipo_trab2=-1.
IF pea=1				tipo_trab2=tip_trab.2.
IF (pea=0 or pea=2)			tipo_trab2=9.
IF sysmiss(pea)				tipo_trab2=9.
IF edad<16				tipo_trab2=9.
RECODE tipo_trab2 (9 =sysmiss).
VARIABLE LABELS tipo_trab2 "Tipo de trabajador en ocupacin secundaria".
VALUE LABELS tipo_trab2	1"Depende de un patrn, jefe o sup"
				2 "No depende de un jefe y tiene asignado un sueldo"
				3 "No depende de un jefe y no recibe o tiene asignado un sueldo".
FORMATS tipo_trab2 (F1).

*********************************************************
* JUBILADOS O PENSIONADOS*.
*********************************************************.

COMPUTE 				jub=0.
IF trabajo="2" & bustrab_3="3"		jub=1.
IF ing_pens>0		                      	jub=1.
IF inscr_2="2"	                     		jub=1.
VARIABLE LABELS  jub " Poblacin pensionada o jubilada".
VALUE LABELS  jub 	0 "Poblacin no pensionada o jubilada"
                                    1 "Poblacin pensionada o jubilada".
FORMATS jub(F1).

*****************************************************************************
*  PRESTACIONES BSICAS
*****************************************************************************.

*****LABORALES*****.
*Las prestaciones de incapacidad con goce de sueldo y afore recibida como
prestacin laboral ya han sido definidas:.

*Incapacidad con goce de sueldo en ocupacin principal:inclab1*.
*Incapacidad con goce de sueldo ocupacin secundaria: inclab2*.

*Afore por prestacin laboral ocupacin principal: aforlab1*. 
*Afore por prestacin laboral ocupacin secundaria: aforlab1*. 

*Prestaciones laborales (Servicios mdicos).
*Ocupacin principal*.

COMPUTE smlab1=-1.
IF ocupa1=1 & atemed="1" & (inst_1="1" | inst_2="2" | inst_3="3" | inst_4="4")  & inscr_1="1"		smlab1=1.
IF ocupa1=1 & atemed="1" & (inst_1="1" | inst_2="2" | inst_3="3" | inst_4="4") & inscr_1=""	smlab1=0.
IF ocupa1=1 & atemed="2"  | 
(atemed="1" & (inst_1="" & inst_2="" & inst_3="" & inst_4="" & inst_4="") & (inst_5="5" ))		smlab1=0.
IF sysmiss(ocupa1)											smlab1=9.
RECODE smlab1(9=SYSMISS).
VARIABLE LABELS smlab1 "Servicios mdicos por prestacin laboral en ocupacion principal ".
VALUE LABELS smlab1 0 "Sin servicios mdicos" 
1 "Con servicios mdicos".
FORMATS smlab1 (F1).

*Ocupacin secundaria*.

COMPUTE smlab2=-1.
IF ocupa2=1 & atemed="1" & (inst_1="1" | inst_2="2" | inst_3="3" | inst_4="4")  & inscr_1="1"		smlab2=1.
IF ocupa2=1 & atemed="1" & (inst_1="1" | inst_2="2" | inst_3="3" | inst_4="4") & inscr_1=""	smlab2=0.
IF ocupa2=1 & atemed="2" | 
(atemed="1" & (inst_1="" & inst_2="" & inst_3="" & inst_4="") & (inst_5="5" ))		smlab2=0.
IF ocupa2=0					                 smlab2=9.
IF sysmiss(ocupa2)											smlab2=9.
RECODE smlab2(9=SYSMISS).
VARIABLE LABELS smlab2 "Servicios mdicos por prestacin laboral en ocupacion secundaria ".
VALUE LABELS smlab2 0 "Sin servicios mdicos" 
1 "Con servicios mdicos".
FORMATS smlab2 (F1).

****CONTRATACIN VOLUNTARIA: servicios medicos y SAR o Afore*****.

*Servicios mdicos *.

COMPUTE 				smcv=-1.
IF edad>=12 & atemed="1" & (inst_1="1" | inst_2="2" | inst_3="3" | inst_4="4") & inscr_6="6"		smcv=1.
IF edad>=12 & atemed="1" & (inst_1="1" | inst_2="2" | inst_3="3" | inst_4="4") & inscr_6=""  	smcv=0.
IF edad>=12 & atemed="2"	smcv=0.
IF edad>=12 & atemed="1" & (inst_1="" & inst_2="" & inst_3="" & inst_4="") & (inst_5="5" ) 		smcv=0.
IF edad<12				smcv=9.
RECODE smcv(9=SYSMIS).
VARIABLE LABELS smcv "Servicios mdicos por contratacin voluntaria ".
VALUE LABELS smcv 	0 "No cuenta "
		1 "Si cuenta ".
FORMATS smcv (F1).

*SAR o Afore*.

COMPUTE 			aforecv=-1.
IF edad>=12 & segvol_1="1"	aforecv=1.
IF edad>=12 & segvol_1=""	aforecv=0.
IF edad<12 			aforecv=9.
RECODE aforecv (9=SYSMIS).
VARIABLE LABELS aforecv "SAR o Afore".
VALUE LABELS aforecv		0 "No cuenta"
                        	    	1 "S cuenta ".
FORMATS aforecv (F1).

************************************************************************************
* INDICADOR DE ACCESO DIRECTO A LA SEGURIDAD SOCIAL
************************************************************************************ .
*A partir de la informacin anterior se identificar el acceso directo
a la seguridad social de acuerdo a los siguientes criterios:
*
-Si es ocupada y en cualquiera de sus trabajos es subordinada y recibe 
como prestacin laboral servicios mdicos, incapacidad con goce de sueldo 
y SAR o Afore
-Si es ocupada y en cualquiera de sus trabajos es independiente con un sueldo
o pago asignado y dispone de servicios mdicos y SAR o Afore como prestacin 
laboral o por contratacin propia
-Si es ocupada y en cualquiera de sus trabajos es independiente sin sueldo
o pago asignado y dispone de servicios mdicos como prestacin laboral y 
SAR o Afore por contratacin propia
-Si es jubilada o pensionada.
*******************************************************************************************

COMPUTE						ss_dir=-1.
* Ocupacion principal.  
IF tipo_trab1=1 &  smlab1=1 & inclab1=1 & aforlab1=1 		ss_dir=1.
IF tipo_trab1=2 & (smlab1=1 | smcv=1) & (aforlab1=1 | aforecv=1)  	ss_dir=1.
IF tipo_trab1=3 & (smlab1=1 | smcv=1) & (aforecv=1) 		ss_dir=1.

*Ocupacion secundaria.  
IF tipo_trab2=1 & smlab2=1 & inclab2=1 & aforlab2=1  		ss_dir=1.
IF tipo_trab2=2 & (smlab2=1 | smcv=1) & (aforlab2=1  | aforecv=1)  	ss_dir=1.
IF tipo_trab2=3 & (smlab2=1 | smcv=1) & (aforecv=1)  		ss_dir=1.

*Jubilados y pensionados.
IF  jub=1						ss_dir=1.
RECODE ss_dir (-1=0)(1 THRU 7=1)(99=9).
VARIABLE LABELS ss_dir "Acceso directo a la seguridad social".
VALUE LABELS ss_dir  0 "Sin acceso"
		1 "Con acceso".
FORMATS ss_dir(F1).

********************************************************************************************.
*		ACCESO POR  NUCLEOS FAMILIARES
********************************************************************************************.
*En primer lugar se identifican los principales parentescos respecto
a la jefatura del hogar.

COMPUTE			par=6.
IF (parentesco>="100" & parentesco<"200") par=1.
IF (parentesco>="200" & parentesco<"300") par=2.
IF (parentesco>="300" & parentesco<"400") par=3.
IF parentesco="601" par=4.
IF parentesco="615" par=5.
VARIABLE LABELS  par "Integrantes que tienen acceso por otros miembros".
VALUE LABELS  par 	1 "Jefe/a de hogar"
	2 "Cnyuge del jefe/a"
	3 "Hijo del jefe/a"
	4 "Padre o Madre del jefe/a"
	5 "Suegro del jefe/a"
	6 "Sin parentesco directo".
FORMATS par (F1).

*Asimismo, se utilizar la informacin relativa a la asistencia a la 
escuela.

* INASISTENCIA A LA ESCUELA (se reporta para personas de 3 aos y ms)*.

COMPUTE             inas_esc=-1.
IF asis_esc="1"        inas_esc=0.
IF asis_esc="2"        inas_esc=1.
IF edad<3              inas_esc=99.
RECODE inas_esc(99=SYSMIS).
VARIABLE LABELS inas_esc "Inasistencia a la escuela".
VALUE LABELS  inas_esc   1 "No asiste"
                                        0 "S asiste".
FORMATS inas_esc (F1).

*Para la identificacin del acceso a travs de ncleos familiares
se identifica a nivel hogar si los integrantes que pueden otorgar
el acceso disponen del mismo.

* AUXILIARES QUE IDENTIFICAN SI UN MIEMBRO DEL HOGAR CUENTA O NO CON ACCESO A LA SEG SOCIAL*.
*En primer lugar se identifican los principales parentescos respecto
a la jefatura del hogar.

COMPUTE			jef=0.
IF par=1 & ss_dir=1		jef=1.
FORMATS jef(F1).

COMPUTE			cony=0.
IF par=2 & ss_dir=1		cony=1.
FORMATS cony(F1).

COMPUTE 			hijo=0.
IF par=3 & ss_dir=1	& jub=0 hijo=1.
IF par=3 & ss_dir=1 & jub=1  & edad>25     hijo=1.
FORMATS hijo(F1).

AGGREGATE
  /OUTFILE=* MODE=ADDVARIABLES
  /BREAK=proyecto folioviv foliohog
  /jef_sum=SUM(jef) 
  /cony_sum=SUM(cony) 
  /hijo_sum=SUM(hijo).

RECODE jef_sum      (1 thru HI=1)(ELSE=COPY) INTO jef_ss.
VARIABLE LABELS jef_ss "Acceso directo a la seguridad social de la jefatura del hogar".
VALUE LABELS  jef_ss  0 "No cuenta"
1 "S cuenta".
FORMATS jef_ss (F1). 

RECODE cony_sum  (1 thru HI=1)(ELSE=COPY) INTO cony_ss.
VARIABLE LABELS cony_ss "Acceso directo a la seguridad social de cnyuge de la jefatura del hogar".
VALUE LABELS  cony_ss  0 "No cuenta"
1 "S cuenta".
FORMATS cony_ss (F1).

RECODE hijo_sum    (1 thru HI=1)(ELSE=COPY) INTO hijo_ss.
VARIABLE LABELS hijo_ss "Acceso directo a la seguridad social de hijos(as) de la jefatura del hogar".
VALUE LABELS  hijo_ss  0 "No cuenta"
1 "S cuenta".
FORMATS hijo_ss (F1).

*******************************************************************************************
*	OTROS NUCLEOS FAMILIARES
********************************************************************************************.
*Asimismo, se identifica a la poblacin con acceso a la seguridad
social mediante otros ncleos familiares a travs de la afiliacin
o inscripcin a servicios de salud por algn familiar dentro o
fuera del hogar, muerte del asegurado o por contratacin propia.

COMPUTE                  			s_salud=-1.
IF atemed="2"   		s_salud=0. 
IF atemed="1" & (inst_1="1" | inst_2="2" | inst_3="3" | inst_4="4")  & (inscr_3="3" or inscr_7="7" or inscr_4="4" or inscr_6="6")	s_salud=1. 
IF atemed="1" & (inst_1="1" | inst_2="2" | inst_3="3" | inst_4="4")  & (inscr_3="" & inscr_7="" & inscr_4="" & inscr_6="")	s_salud=0. 
IF atemed="1" & (inst_1="" & inst_2="" & inst_3="" & inst_4="" & inst_5="5")  	s_salud=0. 
IF atemed=""		& (inst_1="" & inst_2="" & inst_3="" & inst_4="" & inst_5="") &
(inscr_3="" & inscr_7="" & inscr_4="" & inscr_6="")	s_salud=9.
RECODE s_salud(9=sysmiss).
VARIABLE LABELS  s_salud "Servicios mdicos por otros ncleos familiares o por contratacin propia".
VALUE LABELS  s_salud		0 "No cuenta"
	1 "S cuenta".
FORMATS s_salud (F1).

*********************************************************************************************************
*		PROGRAMAS SOCIALES DE PENSIONES PARA  DE ADULTOS MAYORES
*********************************************************************************************************.

COMPUTE 						pam=-1.
IF (edad>=65 &  ing_pam>0)		pam=1.
IF (edad>=65 &  (ing_pam=0 | sysmiss(ing_pam)))			pam=0.
IF edad<65						pam=9.
RECODE pam (9=SYSMIS).
VARIABLE LABELS  pam "Programa de adultos mayores".
VALUE LABELS pam 0 "No recibe"
                           1 "Recibe".
FORMATS pam (F1).

***********************************************************************************************************
*
*	INDICADOR DE CARENCIA POR ACCESO A LA SEGURIDAD SOCIAL
*
*************************************************************************************************************.
*
No se considera en situacin de carencia por acceso a la seguridad social
a la poblacin que:
*
1. Disponga de acceso directo a la seguridad social,
2. Cuente con parentesco directo con alguna persona dentro del hogar
que tenga acceso directo,
3. Reciba servicios mdicos por parte de algn familiar dentro o
fuera del hogar, por muerte del asegurado o por contratacin propia, o,
4. Reciba ingresos por parte de un programa de adultos mayores
*
Se considera en situacin de carencia por acceso a la seguridad social
aquella poblacin:
*
1. En cualquier otra situacin.
***********************************************************************.

COMPUTE 					ic_segsoc=1.

*Acceso directo.
IF ss_dir=1					ic_segsoc=0.

*Parentesco directo: jefatura.
IF par=1 & cony_ss=1				ic_segsoc=0.
IF par=1 & pea=0 	& hijo_ss=1			ic_segsoc=0.

*Parentesco directo: cnyuge.
IF par=2 & jef_ss=1				ic_segsoc=0.
IF par=2 & pea=0 	& hijo_ss=1			ic_segsoc=0.

*Parentesco directo: descendientes.
IF par=3 & edad<16 	& jef_ss=1			ic_segsoc=0.
IF par=3 & edad<16 	& cony_ss=1		ic_segsoc=0.
IF par=3 & (16<=edad & edad<=25) & inas_esc=0 & jef_ss=1	ic_segsoc=0.
IF par=3 & (16<=edad & edad<=25) & inas_esc=0 & cony_ss=1	ic_segsoc=0.

*Parentesco directo: ascendientes.
IF par=4 & pea=0 	& jef_ss=1			ic_segsoc=0.
IF par=5 & pea=0 	& cony_ss=1		ic_segsoc=0.

*Otros ncleos familiares.
IF s_salud=1				ic_segsoc=0.

*Programa de adultos mayores.
IF pam=1					ic_segsoc=0.
VARIABLE LABELS  ic_segsoc "Indicador de carencia por acceso a la seguridad social".
VALUE LABELS ic_segsoc 0 " Con acceso"
		1 "Sin acceso"
		99 "NR".
FORMATS ic_segsoc(F1).

*Se salva la base con el indicador de seguridad social.
	SAVE OUTFILE='C:\Medicion\2010\SPSS\Bases\IC_SEGSOC10.sav'
	/KEEP= proyecto folioviv foliohog numren tipo_trab1 tipo_trab2 inclab1 inclab2  aforlab1 aforlab2 
smlab1 	smlab2 smcv aforecv pea jub ss_dir par jef_ss cony_ss hijo_ss 	s_salud pam ic_segsoc
	 /COMPRESSED.

**********************************************************************************************
* Parte IV Indicadores de Privacin Social:
*
* INDICADOR DE CARENCIA POR CALIDAD Y ESPACIOS DE LA VIVIENDA 
*
********************************************************************************************** .
*Para la construccin del indicador de carencia por calidad
y espacios de la vivienda se utilizan las variables de material
de pisos, material de techos, material de muros, nmero de cuartos
en la vivienda y total de residentes en la vivienda.
*******************************************************************************************

******************************************************************
*	 MATERIAL DE CONSTRUCCIN DE LA VIVIENDA
******************************************************************.
GET
  FILE='C:\Medicion\2010\SPSS\MCS\concentrado.sav'.

SORT CASES BY proyecto(A) folioviv(A) foliohog(A).

SAVE OUTFILE='C:\Medicion\2010\SPSS\Bases\concentrado.sav'
  /COMPRESSED.

GET
  FILE='C:\Medicion\2010\SPSS\MCS\hogares.sav'.

*En los casos donde hay ms de un hogar en la vivienda, la informacin
a nivel vivienda slo se reporta para los hogares principales, por lo cual 
se imputa la caracterstica del hogar principal a los hogares secundarios.

SORT CASES BY proyecto(A) folioviv(A) foliohog(A).

MATCH FILES /FILE=*
  /FILE='C:\Medicion\2010\SPSS\Bases\concentrado.sav'
  /RENAME (conapo  est_dis factor ubica_geo upm = d0  d2 d3 d4 d5) 
  /IN merge1
  /BY proyecto folioviv foliohog
  /DROP= d0  d2 d3 d4 d5.
VARIABLE LABELS merge1 'Case source is '+
    'C:\Medicion\2010\SPSS\Bases\concentrado.sav'.
EXECUTE.

RECODE pisos ("-1"="")(ELSE=COPY).
COMPUTE pisos2=NUMBER(pisos,F1).
COMPUTE techos2=NUMBER(techos,F1).
COMPUTE pared2=NUMBER(pared,F1).

AGGREGATE
  /OUTFILE=* MODE=ADDVARIABLES
  /BREAK=proyecto folioviv 
  /pisosv=SUM(pisos2) 
  /techov=SUM(techos2) 
  /murov=SUM(pared2)
  /tot_resi_sum=SUM(tot_resi) 
  /cuar_sum=SUM(cuart).
EXECUTE.

*MATERIAL DE PISO DE LA VIVIENDA.

RECODE pisosv (ELSE=COPY) INTO cv_pisos.
VARIABLE LABELS  cv_pisos 	"Material de pisos".
VALUE LABELS  cv_pisos    1 Tierra
                         2 Cemento o firme
																									3 Madera, mosaico u otro recubrimiento.
FORMATS cv_pisos (F1).

* MATERIAL DE LOS TECHOS DE LA VIVIENDA.

RECODE techov (7=8)(8=7)(ELSE=COPY) INTO cv_techos.
VARIABLE LABELS  cv_techos 	"Material de techos".
VALUE LABELS  cv_techos 1 Desecho
                          2 Lmina de cartn
																									 3 Lmina metlica
                          4 Lmina de asbesto 
																									 5 Palma o paja
																									 6 Madera o tejamanil
																									 7 Teja
                          8 Terrado con viguera
                          9 Losa de concreto o viguetas con bovedilla.
FORMATS cv_techos (F1).

* MATERIAL DE MUROS DE LA VIVIENDA.

RECODE murov (ELSE=COPY) INTO cv_muros.
VARIABLE LABELS  cv_muros 	"Material de muros".
VALUE LABELS  cv_muros 1 Desecho
                          2 Lmina de cartn
																									 3 Lmina metlica o de asbesto
																									 4 Carrizo, bamb o palma
																									 5 Embarro o bajareque
																									 6 Madera
                          7 Adobe
                          8 Tabique, ladrillo, block piedra o concreto.
FORMATS cv_muros (F1).

************************************************************
* ESPACIOS DE LA VIVIENDA
*************************************************************.

*NDICE DE HACINAMIENTO.

* Nmero de residentes en la vivienda.

COMPUTE num_ind=tot_resi_sum.
VARIABLE LABELS  num_ind "Nmero de residentes en la vivienda".
FORMATS num_ind (F2).

* Nmero de cuartos de la vivienda.

COMPUTE num_cua=cuar_sum.
VARIABLE LABELS num_cua "Nmero de cuartos en la vivienda".
FORMATS num_cua (F2).

COMPUTE cv_hac=(num_ind/num_cua).
VARIABLE LABELS  cv_hac "ndice de hacinamiento de la vivienda".
FORMATS cv_hac(F1).

*A partir de las variables anteriores se construyen los sub-indicadores
que componen al indicador de carencia de esta dimensin.

*INDICADOR DE CARENCIA DEL MATERIAL DE PISOS DE LA VIVIENDA.

COMPUTE      icv_pisos=-1.
IF cv_pisos=1    icv_pisos=1.
IF cv_pisos>1  icv_pisos=0.
RECODE icv_pisos(-1=sysmiss).
VARIABLE LABELS  icv_pisos "Indicador de carencia del material de piso de la vivienda".
VALUE LABELS icv_pisos 0 "Sin carencia"
1 "Con carencia".
FORMATS icv_pisos(F1).

*INDICADOR DE CARENCIA DEL MATERIAL DE TECHO DE LA VIVIENDA.

COMPUTE                                    icv_techos=-1.
IF cv_techos<=2                            icv_techos=1.
IF cv_techos>2     icv_techos=0.
RECODE icv_techos(-1=sysmiss).
VARIABLE LABELS icv_techos "Indicador de carencia del material de techos de la vivienda".
	VALUE LABELS icv_techos 0 "Sin carencia"
1 "Con carencia".
FORMATS icv_techos(F1).

*INDICADOR DE CARENCIA DEL MATERIAL DE MUROS DE LA VIVIENDA.

COMPUTE                                  icv_muros=-1.
IF cv_muros<=5                           icv_muros=1.
IF 5<cv_muros      icv_muros=0.
RECODE icv_muros(-1=sysmiss).
VARIABLE LABELS icv_muros "Indicador de carencia del material de muros de la vivienda".
VALUE LABELS icv_muros 0 "Sin carencia"
1 "Con carencia".
FORMATS icv_muros(F1).

*INDICADOR DE CARENCIA POR NDICE DE HACINAMIENTO.

COMPUTE                                icv_hac=0.
IF cv_hac>2.5                           icv_hac=1.
VARIABLE LABELS icv_hac "Indicador de carencia por ndice de hacinamiento de la vivienda".
VALUE LABELS icv_hac 0 "Sin carencia"
1 "Con carencia".
FORMATS icv_hac(F1).

***********************************************************************************************************
*
*		         INDICADOR DE CARENCIA POR CALIDAD Y ESPACIOS DE LA VIVIENDA 
*
********************************************************************************************************** .
*
Se considera en situacin de carencia por calidad y espacios 
de la vivienda a la poblacin que:
*
1. Presente carencia en cualquiera de los subindicadores de esta dimensin
*
No se considera en situacin de carencia por rezago calidad y espacios 
de la vivienda a la poblacin que:
*
1. Habite en una vivienda sin carencia en todos los subindicadores
de esta dimensin
***********************************************************************.

COMPUTE                                                                        ic_cv=-1.
IF (icv_pisos=1 | icv_techos=1 | icv_muros=1 | icv_hac=1 )      ic_cv=1.
IF (icv_pisos=0 & icv_techos=0 & icv_muros=0 & icv_hac=0 )  ic_cv=0.
IF (sysmiss(icv_pisos) | sysmiss(icv_techos) | sysmiss(icv_muros) | sysmiss(icv_hac=1)) ic_cv=9.
VARIABLE LABELS ic_cv "Indicador de carencia por calidad y espacios de la vivienda".
	VALUE LABELS ic_cv  1 "Con carencia"
            		                         0 "Sin carencia".
RECODE ic_cv(9=SYSMIS).
FORMATS ic_cv (F1).

SORT CASES proyecto(A) folioviv(A) foliohog(A).

SAVE OUTFILE='C:\Medicion\2010\SPSS\Bases\IC_CEV10.sav'
 /KEEP =  proyecto folioviv foliohog  cv_pisos cv_techos cv_muros num_ind num_cua 
cv_hac icv_pisos icv_techos icv_muros icv_hac ic_cv
 /COMPRESSED.

**********************************************************************************************
* Parte V Indicadores de Privacin Social:
*
* INDICADOR DE CARENCIA POR ACCESO A LOS SERVICIOS BSICOS EN LA VIVIENDA 
*
********************************************************************************************.

GET
  FILE='C:\Medicion\2010\SPSS\MCS\hogares.sav'.

*Para la construccin del indicador de carencia por calidad
y espacios de la vivienda se utiliza informacin sobre la disponibilidad
de los servicios de electricidad, agua y drenaje.

*En los casos donde hay ms de un hogar en la vivienda, la informacin
a nivel vivienda slo reporta para los hogares principales, por lo cual
se imputa la caracterstica correspondiente a los hogares secundarios.

COMPUTE agua13=NUMBER(dis_agua,F1).
COMPUTE drenaje2=NUMBER(drenaje,F1).
COMPUTE elect2=NUMBER(elect,F1).

SORT CASES BY proyecto(A) folioviv(A) foliohog(A).
AGGREGATE
  /OUTFILE=* MODE=ADDVARIABLES
  /BREAK=proyecto folioviv 
  /aguav=SUM(agua13) 
  /drenajev=SUM(drenaje2) 
  /elecv=SUM(elect2).
EXECUTE.

*ACCESO AL AGUA EN LA VIVIENDA.

RECODE aguav (6=1)(5=2)(4=3)(3=4)(2=5)(1=6) INTO sb_agua.
VARIABLE LABELS  sb_agua 	"Acceso al agua".
VALUE LABELS sb_agua   1 Pozo, ro, lago, arroyo u otro
                         2 Pipa
                         3 Entubada de la llave pblica o hidrante 
																									4 Entubada que acarrea de otra vivienda
																									5 Entubada fuera de la vivienda pero dentro del terreno
																									6 Entubada dentro de la vivienda.
FORMATS sb_agua (F1).

* ACCESO AL SERVICIO DE DRENAJE EN LA VIVIENDA.

RECODE drenajev (5=1)(4=2)(3=3)(2=4)(1=5) INTO sb_dren.
VARIABLE LABELS sb_dren 	"Servicio de drenaje".
VALUE LABELS  sb_dren    1 No tiene drenaje
                          2 Conectado a una tubera que va a dar a un ro, lago o mar
																									 3 Conectado a una tubera que va a dar a una barranca o grieta
                          4 Conectado a una fosa sptica
																									 5 Conectado a la red pblica.
FORMATS sb_dren (F1).

*ACCESO AL SERVICIO DE ELECTRICIDAD.

RECODE elecv (5=1)(3 4=2)(2=3)(1=4) INTO sb_luz.
VARIABLE LABELS sb_luz 	"Servicio de electricidad".
VALUE LABELS sb_luz      1 No tiene luz elctrica
                          2 Panel solar o de otra fuente
																									 3 Planta particular
																									 4 Servicio pblico.
FORMATS sb_luz (F1).

*A partir de las variables anteriores se construyen los sub-indicadores
que componen el indicador de carencia de esta dimensin.

*INDICADOR DE CARENCIA DE ACCESO AL AGUA.

COMPUTE                           isb_agua=-1.
IF sb_agua<=4                     isb_agua=1.
IF sb_agua>4                       isb_agua=0.
VARIABLE LABELS isb_agua "Indicador de carencia de acceso al agua".
VALUE LABELS isb_agua 0 "Sin carencia"
                                        1 "Con carencia".
FORMATS isb_agua(F1).

*INDICADOR DE CARENCIA DE SERVICIO DE DRENAJE.

COMPUTE                           isb_dren=-1.
IF sb_dren<=3                     isb_dren=1.
IF sb_dren>3                       isb_dren =0.
VARIABLE LABELS isb_dren "Indicador de carencia de servicio de drenaje".
VALUE LABELS isb_dren 0 "Sin carencia"
                                        1 "Con carencia".
FORMATS isb_dren(F1).

*INDICADOR DE CARENCIA DE SERVICIOS DE ELECTRICIDAD.

COMPUTE                           isb_luz=-1.
IF sb_luz=1                         isb_luz=1.
IF sb_luz>1                       isb_luz =0.
VARIABLE LABELS isb_luz "Indicador de carencia de servicios de electricidad".
VALUE LABELS isb_luz   0 "Sin carencia"
                                        1 "Con carencia".
FORMATS isb_luz(F1).

***********************************************************************************************************
*
*		         INDICADOR DE CARENCIA POR DE ACCESO A SERVICIOS BSICOS DE LA VIVIENDA
*
********************************************************************************************************** .
*
Se considera en situacin de carencia por servicios bsicos
en la vivienda a la poblacin que:
*
1. Presente carencia en cualquiera de los subindicadores de esta dimensin
*
No se considera en situacin de carencia por servicios bsicos
en la vivienda a la poblacin que:
*
1. Habite en una vivienda sin carencia en todos los subindicadores
de esta dimensin
***********************************************************************.

COMPUTE                                                                    ic_sbv=-1.
IF (isb_agua=1 | isb_dren=1 | isb_luz=1 ) ic_sbv=1 .
IF (isb_agua=0 & isb_dren=0 & isb_luz=0  ) ic_sbv=0.
IF sysmiss(isb_agua) | sysmiss(isb_dren) | sysmiss(isb_luz) ic_sbv=9.
VARIABLE LABELS ic_sbv "Indicador de carencia de acceso a servicios bsicos de la vivienda".
VALUE LABELS ic_sbv  0 "Sin carencia"
                                        1 "Con carencia".
RECODE  ic_sbv(9=SYSMIS).
FORMATS ic_sbv (F1).


SORT CASES  proyecto(A) folioviv(A) foliohog(A).


SAVE OUTFILE='C:\Medicion\2010\SPSS\Bases\IC_SBV10.sav'
 /KEEP =  proyecto folioviv foliohog sb_agua sb_dren sb_luz isb_agua 
isb_dren isb_luz ic_sbv
 /COMPRESSED.

**********************************************************************************************
* Parte VI  Indicadores de Privacin social:
*
* INDICADOR DE CARENCIA POR ACCESO A LA ALIMENTACIN
*
**********************************************************************************************.
* Esta escala incluye 12 preguntas que se diferencian por los miembros 
del hogar, esto es hogares donde habitan menores de 18 aos y hogares 
donde NO habitan menores de 18 aos.
**********************************************************************************************************.

GET
  FILE='C:\Medicion\2010\SPSS\MCS\poblacion.sav'.

* Poblacin objeto: no se incluye a huspedes ni trabajadores domsticos.

SELECT IF  ~("400"<=parentesco & parentesco<"500"). 
SELECT IF  ~("700"<=parentesco & parentesco<"800"). 

* INDICADOR DE HOGARES CON INTEGRANTES MENORES DE 18 AOS

COMPUTE          men=-1.
IF edad<18         men=1.
IF edad>=18       men=0.

AGGREGATE
  /OUTFILE='C:\Medicion\2010\SPSS\Bases\menores10.sav'
  /BREAK=proyecto folioviv foliohog
  /men_sum=SUM(men)
  /N_BREAK=N.

GET
  FILE='C:\Medicion\2010\SPSS\Bases\menores10.sav'.

COMPUTE               id_men=0.
IF men_sum>=1      id_men=1.
VARIABLE LABELS  id_men "Hogares con poblacin de 0 a 17 aos de edad".
VALUE LABELS id_men 0"Sin poblacin de 0 a 17 aos"
                                 1"Con poblacin de 0 a 17 aos".
FORMATS id_men(F1).


SORT CASES proyecto(A) folioviv(A) foliohog(A).

SAVE OUTFILE='C:\Medicion\2010\SPSS\Bases\menores10.sav'
 /KEEP = proyecto folioviv foliohog  id_men
 /COMPRESSED.

********************************************************************************
* ESCALA DE INSEGURIDAD ALIMENTARIA
*********************************************************************************.

GET
  FILE='C:\Medicion\2010\SPSS\MCS\hogares.sav'.

* 	SEIS PREGUNTAS PARA HOGARES SIN POBLACIN MENOR A 18 AOS.

COMPUTE alim1_2=NUMBER(alim1,F1).
COMPUTE alim2_2=NUMBER(alim2,F1).
COMPUTE alim3_2=NUMBER(alim3,F1).
COMPUTE alim4_2=NUMBER(alim4,F1).
COMPUTE alim5_2=NUMBER(alim5,F1).
COMPUTE alim6_2=NUMBER(alim6,F1).
COMPUTE alim7_2=NUMBER(alim7,F1).
COMPUTE alim8_2=NUMBER(alim8,F1).
COMPUTE alim9_2=NUMBER(alim9,F1).
COMPUTE alim10_2=NUMBER(alim10,F1).
COMPUTE alim11_2=NUMBER(alim11,F1).
COMPUTE alim12_2=NUMBER(alim12,F1).
COMPUTE alim13_2=NUMBER(alim13,F1).
COMPUTE alim14_2=NUMBER(alim14,F1).
COMPUTE alim15_2=NUMBER(alim15,F1).
COMPUTE alim16_2=NUMBER(alim16,F1).

RECODE alim4_2 (2=0) (1=1)(SYSMIS=0) INTO ia_1ad.
RECODE alim5_2 (2=0) (1=1)(SYSMIS=0) INTO ia_2ad.
RECODE alim6_2 (2=0) (1=1)(SYSMIS=0) INTO ia_3ad.
RECODE alim2_2 (2=0) (1=1)(SYSMIS=0) INTO ia_4ad.
RECODE alim7_2 (2=0) (1=1)(SYSMIS=0) INTO ia_5ad.
RECODE alim8_2 (2=0) (1=1)(SYSMIS=0) INTO ia_6ad.
FORMATS ia_1ad to ia_6ad(F1).

VARIABLE LABELS ia_1ad "Algn adulto tuvo una alimentacin basada en muy poca variedad de alimentos".
VARIABLE LABELS ia_2ad "Algn adulto dej de desayunar, comer o cenar".
VARIABLE LABELS ia_3ad "Algn adulto comi menos de lo que deba comer".
VARIABLE LABELS ia_4ad "El hogar se qued sin comida".
VARIABLE LABELS ia_5ad "Algn adulto sinti hambre pero no comi".
VARIABLE LABELS ia_6ad "Algn adulto solo comi una vez al da o dej de comer todo un da".

VALUE LABELS  ia_1ad  ia_2ad ia_3ad ia_4ad ia_5ad ia_6ad   0 "No" 1 "S".

* 	SEIS PREGUNTAS PARA HOGARES CON POBLACIN MENOR A 18 AOS.

RECODE alim11_2 (2=0) (1=1) (SYSMIS=0) INTO ia_7men.
RECODE alim12_2 (2=0) (1=1) (SYSMIS=0) INTO ia_8men.
RECODE alim13_2 (2=0) (1=1) (SYSMIS=0) INTO ia_9men.
RECODE alim14_2 (2=0) (1=1) (SYSMIS=0) INTO ia_10men.
RECODE alim15_2 (2=0) (1=1) (SYSMIS=0) INTO ia_11men.
RECODE alim16_2 (2=0) (1=1) (SYSMIS=0) INTO ia_12men.
FORMATS ia_7men to ia_12men(F1).

VARIABLE LABELS ia_7men "Alguien de 0 a 17 aos tuvo una alimentacin basada en muy poca variedad de alimentos".
VARIABLE LABELS ia_8men "Alguien de 0 a 17 aos comi menos de lo que deba".
VARIABLE LABELS ia_9men "Se tuvo que disminuir la cantidad servida en las comidas a alguien de 0 a 17 aos".
VARIABLE LABELS ia_10men "Alguien de 0 a 17 aos sinti hambre pero no comi".
VARIABLE LABELS ia_11men "Alguien de 0 a 17 aos se acost con hambre".
VARIABLE LABELS ia_12men "Alguien de 0 a 17 aos comi una vez al da o dej de comer todo un da".

VALUE LABELS  ia_7men  ia_8men ia_9men ia_10men ia_11men ia_12men   0 "No" 1 "S".

* CONSTRUCCIN DE LA ESCALA DE INSEGURIDAD ALIMENTARIA*.

*Para construir la escala se requiere distinguir entre aquellos hogares
con poblacin de 0 a 17 aos y los que no cuentan con integrantes de esa
edad.

SORT CASES  proyecto(A) folioviv(A) foliohog(A).

MATCH FILES /FILE=*
  /TABLE='C:\Medicion\2010\SPSS\Bases\menores10.sav'
  /BY proyecto folioviv foliohog.
EXECUTE.

*A partir de la escala se define el grado de inseguridad alimentaria de la siguiente forma:
*
-Se considera sin inseguridad alimentaria a los hogares con o sin poblacin 
de 0 a 17 aos que no reportaron respuestas afirmativas
*
-Se consideran con inseguridad alimentaria leve a los hogares que no tienen
poblacin de 0 a 17 aos y que respondieron afirmativamente a un mximo de
dos preguntas de la escala
*
-Se consideran con inseguridad alimentaria leve a los hogares que cuentan con
poblacin de 0 a 17 aos y que respondieron afirmativamente a un mximo de
tres preguntas de la escala
*
-Se consideran con inseguridad alimentaria moderada a los hogares que no 
tienen poblacin de 0 a 17 aos y que respondieron afirmativamente a tres 
o cuatro preguntas de la escala
*
-Se consideran con inseguridad alimentaria moderada a los hogares que cuentan 
con poblacin de 0 a 17 aos y que respondieron afirmativamente de cuatro a 
siete preguntas de la escala
*
-Se consideran con inseguridad alimentaria grave a los hogares que no 
tienen poblacin de 0 a 17 aos y que respondieron afirmativamente a cinco 
o ms preguntas de la escala
*
-Se consideran con inseguridad alimentaria moderada a los hogares que cuentan 
con poblacin de 0 a 17 aos y que respondieron afirmativamente a ocho o ms 
preguntas de la escala

*********************************************************************************************.

*ESCALA PARA HOGARES SIN MENORES DE 18 AOS*.

COMPUTE           tot_iaad=-1.
IF id_men=0         tot_iaad=SUM(ia_1ad to ia_6ad).
IF id_men=1         tot_iaad=99.
VARIABLE LABELS  tot_iaad "Escala de IA para hogares sin menores de 18 aos".
RECODE tot_iaad (-1 99=SYSMIS).
FORMATS tot_iaad(F1).

*ESCALA PARA HOGARES CON MENORES DE 18 AOS*.

COMPUTE           tot_iamen=-1.
IF id_men=1         tot_iamen=SUM(ia_1ad to ia_6ad, ia_7men to ia_12men).
IF id_men=0         tot_iamen=99.
VARIABLE LABELS  tot_iamen "Escala de IA para hogares con menores de 18 aos".
RECODE tot_iaad (-1 99=SYSMIS).
FORMATS tot_iamen(F1).

**********************************************************************************************************
*                       GRADO DE INSEGURIDAD ALIMENTARIA
* 
* Este subindicador genera cuatro clasificaciones de la siguiente forma:
*					+ Sin inseguridad alimentaria
*	    + Inseguridad alimentaria leve
*     + Inseguridad alimentaria moderada
*     + Inseguridad alimentaria severa
**********************************************************************************************************.

COMPUTE                           																																																															                 	ins_ali=-1.
IF tot_iaad=0 | tot_iamen=0   																																																													                   	ins_ali= 0.
IF (tot_iaad=1 | tot_iaad=2) | (tot_iamen=1 | tot_iamen=2 |tot_iamen=3)                      ins_ali=1.
IF (tot_iaad=3 | tot_iaad=4) | (tot_iamen=4 | tot_iamen=5 |tot_iamen=6 |tot_iamen=7)  ins_ali=2.
IF (tot_iaad=5 | tot_iaad=6) | (8<=tot_iamen & tot_iamen<99)                                    ins_ali=3.
VARIABLE LABELS  ins_ali "Grado de inseguridad alimentaria".
VALUE LABELS  ins_ali  0 "Seguridad alimentaria"
                     1 "Inseguridad alimentaria leve"
                     2 "Inseguridad alimentaria moderada"
                     3 "Inseguridad alimentaria severa".
FORMATS ins_ali (F1).
MISSING VALUES ins_ali (-1).


***********************************************************************************************************
*
*		         INDICADOR DE CARENCIA POR ACCESO A LA ALIMENTACIN 
*
********************************************************************************************************** .
*
Se considera en situacin de carencia por acceso a la alimentacin 
a la poblacin en hogares que:
*
1. Presenten inseguridad alimentaria moderada o severa
*
No se considera en situacin de carencia por acceso a la alimentacin 
a la poblacin que:
*
1. No presente inseguridad alimentaria o un grado de inseguridad 
alimentaria leve

***********************************************************************.

COMPUTE                    ic_ali=-1.
IF ins_ali=2 | ins_ali=3   ic_ali=1.
IF ins_ali=0 | ins_ali=1   ic_ali=0.
VARIABLE LABELS ic_ali "Indicador de carencia por acceso a la alimentacin".
VALUE LABELS ic_ali  0 "Sin carencia"
                                   1 "Con carencia" .
FORMATS ic_ali (F1).

SORT CASES proyecto(A) folioviv(A) foliohog(A).

SAVE OUTFILE='C:\Medicion\2010\SPSS\Bases\IC_ALI10.sav'
 /KEEP =  proyecto folioviv foliohog id_men ia_1ad to ia_6ad ia_7men to ia_12men tot_iaad 
tot_iamen  ins_ali ic_ali
  /COMPRESSED.

**********************************************************************************************
* Parte VII    
*
* BIENESTAR POR INGRESOS
*
********************************************************************************************
*
*Para la construccin del ingreso corriente del hogar es necesario utilizar
informacin sobre la condicin de ocupacin y los ingresos de los individuos.
*
*Se utiliza la informacin contenida en la base de trabajos110.sav y trabajos210.sav
para identificar a la poblacin ocupada que declara tener como prestacin laboral aguinaldo, 
ya sea por su trabajo principal o secundario, a fin de incorporar 
los ingresos por este concepto en la medicin
********************************************************************************************
*
*Creacin del ingreso monetario deflactado a pesos de 
*agosto del 2010.
*
********************************************************.
* Ingresos*.

*En primer lugar se mantienen los ingresos por concepto de la clave "P009"
(ingresos por aguinaldo) nicamente para los trabajadores que en el momento 
de la entrevista tenan derecho a esa prestacin en cualquiera de los empleos
reportados. Para ello, se utiliza la base de trabajos08.dta, la cual luego 
se une a la base de ingresos;

GET
  FILE='C:\Medicion\2010\SPSS\MCS\trabajos.sav'.

SORT CASES  proyecto(A) folioviv(A) foliohog(A) numren(A).

COMPUTE pres2_2=NUMBER(pres_2,F2).
COMPUTE numtrab2=NUMBER(numtrab,F1).
FORMATS pres2_2 numtrab2 (F1).

RECODE pres2_2 (2=1)(SYSMIS=0) INTO pres2.

CASESTOVARS
	/ID=proyecto folioviv foliohog numren
	/INDEX=numtrab2.
EXECUTE.

COMPUTE  trab=1.
VARIABLE LABELS trab "Poblacin con al menos un empleo".

RECODE pres2.2 (sysmiss=0).

COMPUTE                         aguinaldo1=-1.
IF (pres2.1=1)                     aguinaldo1=1.
IF (pres2.1=0)                      aguinaldo1=0.
VARIABLE LABELS aguinaldo1 "Aguinaldo trabajo principal".
VALUE LABELS aguinaldo1 0 "No dispone de  aguinaldo"
		                                      1 "Dispone de aguinaldo".
FORMATS aguinaldo1 (F1).

COMPUTE aguinaldo2=-1.
IF (pres2.2=1) aguinaldo2=1.
IF (pres2.2=0) aguinaldo2=0.
VARIABLE LABELS aguinaldo2 "Aguinaldo trabajo secundario".
VALUE LABELS aguinaldo2 0 "No dispone aguinaldo"
		                                      1 "Dispone de aguinaldo".
FORMATS aguinaldo2 (F1).

SORT CASES by proyecto(A) folioviv (A) foliohog (A).

SAVE OUTFILE='C:\Medicion\2010\SPSS\Bases\aguinaldo10.sav'
 / KEEP = proyecto folioviv foliohog numren pres2.1 pres2.2 aguinaldo1 aguinaldo2 trab
  /COMPRESSED.

*************************************************************
* Parte VII.1
* Creacin del ingreso monetario deflactado a pesos de agosto del 2010. 
* Los deflactores se crean previamente a partir del INPC general (ver Nota Tcnica).
* En esta parte se crea la base: 
* "C:\Medicion\2010\SPSS\Bases\ingreso_deflactado10.sav" 
*la cual se encuentra a nivel de folio del hogar.
*
*************************************************************.

GET
  FILE='C:\Medicion\2010\SPSS\Bases\aguinaldo10.sav'.

SORT CASES by proyecto(A) folioviv (A) foliohog (A) numren(A).

SAVE OUTFILE='C:\Medicion\2010\SPSS\Bases\aux210.sav'
/KEEP = proyecto folioviv foliohog numren.

GET
  FILE='C:\Medicion\2010\SPSS\MCS\ingresos.sav'.

SORT CASES by proyecto(A) folioviv (A) foliohog (A) numren(A).

MATCH FILES /FILE=* /IN = merge1
  /FILE='C:\Medicion\2010\SPSS\Bases\aux210.sav'
  /BY proyecto folioviv foliohog numren.
EXECUTE .

MATCH FILES /FILE=*
  /TABLE='C:\Medicion\2010\SPSS\Bases\aguinaldo10.sav' 
  /IN = merge2
  /BY proyecto folioviv foliohog numren.
EXECUTE .

SELECT IF ~ (clave="P009" & aguinaldo1~=1).
SELECT IF ~ (clave="P016" & aguinaldo2~=1).

*Las variables mes_1 a mes_6 definen los meses a los que los
respondentes recibieron cada uno de los ingresos reportados.

*Se genera la variable 'meses' que define los meses a los que corresponden 
cada uno de los ingresos de la persona en los seis meses 
anteriores al levantamiento de la informacin. Esta variable 
toma cuatro valores:
*
070605040302
080706050403
090807060504
100908070605
*.

STRING meses (A12).
COMPUTE meses=CONCAT( mes_1, mes_2, mes_3, mes_4, mes_5, mes_6).

*****************************************************************************
As, se sabe que la encuesta fue levantada entre los meses de 
agosto y noviembre, y por lo tanto, al preguntarse por los 
ingresos de los seis meses anteriores, se recolect 
informacin correspondiente a los meses de febrero-julio, marzo-agosto, 
abril-septiembre, y mayo-octubre.

*Una vez realizado lo anterior, se procede a deflactar el ingreso recibido
por los hogares a precios de agosto de 2010. Para ellos se utilizan las 
variables meses, las cuales toman los valores 2 a 10 e indican el mes en
que se recibi el ingreso respectivo .

*Definicion de los deflactores 2010.
COMPUTE	 	dic09	 	=	 	0.9814048709	.
COMPUTE	 	ene10	 	=	 	0.9920731621	.
COMPUTE	 	feb10	 	=	 	0.9978110877	.
COMPUTE	 	mar10	 	=	 	1.0048949464	.
COMPUTE	 	abr10	 	=	 	1.0016930422	.
COMPUTE	 	may10	 	=	 	0.9953813241	.
COMPUTE	 	jun10	 	=	 	0.9950696343	.
COMPUTE	 	jul10	 	=	 	0.9972302112	.
COMPUTE	 	ago10	 	=	 	1.0000000000	.
COMPUTE	 	sep10	 	=	 	1.0052420555	.
COMPUTE	 	oct10	 	=	 	1.0114475157	.
COMPUTE	 	nov10	 	=	 	1.0195514501	.
COMPUTE	 	dic10	 	=	 	1.0246022413	.

* La estrategia para deflactar ser dividir cada columna de 
ingreso por el deflactor correspondiente a su mes y la
decena en que fue levantado.

COMPUTE mes = NUMBER(meses, F12) .
IF (SYSMISS (mes)) mes=0.

IF (mes = 070605040302)	ing_6d=	ing_6	 /	feb10.	
IF (mes = 070605040302)	ing_5d=	ing_5	/	mar10.	
IF (mes = 070605040302)	ing_4d=	ing_4	/	abr10.	
IF (mes = 070605040302)	ing_3d=	ing_3	/	may10.	
IF (mes = 070605040302)	ing_2d=	ing_2	/	jun10.	
IF (mes = 070605040302)	ing_1d=	ing_1	/	jul10.	
						
IF (mes = 080706050403)	ing_6d=	ing_6 	/	mar10.	
IF (mes = 080706050403)	ing_5d=	ing_5	/	abr10.	
IF (mes = 080706050403)	ing_4d=	ing_4	/	may10.	
IF (mes = 080706050403)	ing_3d=	ing_3	/	jun10.	
IF (mes = 080706050403)	ing_2d=	ing_2	/	jul10.	
IF (mes = 080706050403)	ing_1d=	ing_1	/	ago10.	
						
IF (mes = 090807060504)	ing_6d=	ing_6 	/	abr10.	
IF (mes = 090807060504)	ing_5d=	ing_5	/	may10.	
IF (mes = 090807060504)	ing_4d=	ing_4	/	jun10.	
IF (mes = 090807060504)	ing_3d=	ing_3	/	jul10.	
IF (mes = 090807060504)	ing_2d=	ing_2	/	ago10.	
IF (mes = 090807060504)	ing_1d=	ing_1	/	sep10.	
							
IF (mes = 100908070605)	ing_6d=	ing_6	/	may10.	
IF (mes = 100908070605)	ing_5d=	ing_5	/	jun10.	
IF (mes = 100908070605)	ing_4d=	ing_4	/	jul10.	
IF (mes = 100908070605)	ing_3d=	ing_3	/	ago10.	
IF (mes = 100908070605)	ing_2d=	ing_2	/	sep10.	
IF (mes = 100908070605)	ing_1d=	ing_1	/	oct10.


*Se deflacta la clave P008 (Reparto de utilidades) con el 
deflactor de mayo a agosto 2008 y la clave P009 y P016 (aguinaldo)
con los deflactores de mayo a agosto 2010
y de diciembre de 2009 a agosto 2010, respectivamente,
y se obtiene el promedio mensual.

IF (clave>="p008" & clave<"p009") or (clave>="p015" & clave<"p016") ing_1d= (ing_1/12)/	may10.	
IF (clave>="p009" & clave<"p010") or (clave>="p016" & clave<"p017") ing_1d= (ing_1/12)/	dic09.	

* Una vez realizada la deflactacin, se procede a obtener el 
ingreso mensual promedio en los ltimos seis meses,
para cada persona y clave de ingreso.

COMPUTE  ing_mens=mean.1( ing_1d, ing_2d, ing_3d, ing_4d, ing_5d, ing_6d).

*Para obtener el ingreso corriente monetario se seleccionan 
las claves de ingreso correspondientes.

IF( ( clave >= 'p001' & clave < 'p010' )	
| ( clave >= 'p011' & clave < 'p017' )
| ( clave >= 'p018' & clave < 'p049' ) 	
| ( clave >= 'p067' & clave < 'p082' )) ing_mon= ing_mens .
IF (SYSMIS(ing_mon)) 	ing_mon = 0.
	VARIABLE LABELS  ing_mon 'Ingreso corriente monetario del hogar'.

SORT CASES by proyecto(A) folioviv (A) foliohog (A) numren(A).

*A continuacin se estima el total de ingresos de cada 
hogar y fuente de ingreso, y se guarda la base en un 
archivo aparte. 

AGGREGATE
/OUTFILE='C:\Medicion\2010\SPSS\Bases\ingreso_deflactado10.sav'
  /BREAK= proyecto folioviv foliohog
  /ing_mon = SUM(ing_mon).
EXECUTE.

************************************************************.

* Parte VII.2 

* Creacin del Ingreso no monetario deflactado a pesos de agosto
de 2010.

* Los deflactores se crean previamente a partir del INPC y aparecen en la Nota Tcnica.

* Se crean las bases: 
'C:\Medicion\\2010\SPSS\Bases\ingresonomonetario_def10.sav' 
a nivel de clave de gasto, y
'C:\Medicion\\2010\SPSS\Bases\auto_def10.sav'
'C:\Medicion\\2010\SPSS\Bases\esp_def10.sav'
'C:\Medicion\\2010\SPSS\Bases\reg_def10.sav' 
a nivel de folio.

****************************************************************************************************************
*No monetario*.

GET
  FILE='C:\Medicion\2010\SPSS\MCS\nomonetarioe.sav'.

SELECT IF ~(proyecto ="1").

RENAME VARIABLES (frecu = frec).
EXECUTE.

STRING frecu (A2).
COMPUTE frecu=CONCAT("0",frec).
If frec="" frecu="00".

SORT CASES by proyecto(A) folioviv (A) foliohog (A).

SAVE OUTFILE='C:\Medicion\2010\SPSS\MCS\nomonetarioef10.sav'
  /COMPRESSED.

GET
  FILE='C:\Medicion\2010\SPSS\MCS\nomonetariom.sav'.

RENAME VARIABLES (frec=frecu).

SORT CASES by proyecto(A) folioviv (A) foliohog (A).

SAVE OUTFILE='C:\Medicion\2010\SPSS\MCS\nomonetariomf10.sav'
  /COMPRESSED.

* Se genera una base que contenga ambos proyectos.

GET
  FILE='C:\Medicion\2010\SPSS\MCS\nomonetarioef10.sav'.

ADD FILES /FILE=*
  /FILE='C:\Medicion\2010\SPSS\MCS\nomonetariomf10.sav'.
EXECUTE.

SAVE OUTFILE='C:\Medicion\2010\SPSS\MCS\nomonetario10.sav'
  /COMPRESSED.

GET
  FILE='C:\Medicion\2010\SPSS\MCS\nomonetario10.sav'.

*En el caso de la informacin de gasto no monetario, para 
deflactar se utiliza la decena de levantamiento de la 
encuesta, la cual se encuentra en la tercera posicin del 
folio de la vivienda. En primer lugar se obtiene una variable que
identifique la decena de levantamiento.

COMPUTE decena = NUMBER(SUBSTR(folioviv,3,1),F2).


*Al comparar con la informacin del catlogo, se observa que la 
informacin se levant en nueve decenas, correspondientes a:

*Decena	Periodo de levantamiento
*
0	|	del 11 al 17 de agosto
1	|	del 21 al 27 de agosto
2	|	del 31 de agosto al 06 de septiembre
3	|	del 10 al 16 de septiembre
4	|	del 20 al 26 de septiembre
5	|	del 30 de septiembre al 06 de octubre
6	|	del 10 al 16 de octubre
7	|	del 20 al 26 de octubre
8	|	del 30 de octubre al 05 de noviembre
9	|	del 09 al 15 de noviembre
Recuperacin 	del 19 al 25 de noviembre

* As, para realizar el anlisis, y conforme a lo establecido
 en la informacin de la MCS2010, se tomarn como periodos 
de referencia:

*
Decena	Periodo de referencia
		/Semanal	/Mensual	/Trimestral		/Semestral
0	|	/Agosto		/Julio		/Mayo a julio		/Febrero a julio
1	|	/Agosto		/Julio		/Mayo a julio		/Febrero a julio
2	|	/Agosto		/Agosto 	/Junio a agosto		/Marzo a agosto 
3	|	/Septiembre	/Agosto		/Junio a agosto		/Marzo a agosto
4	|	/Septiembre	/Agosto		/Junio a agosto		/Marzo a agosto
5	|	/Septiembre	/Septiembre	/Julio a septiembre	/Abril a septiembre
6	|	/Octubre	/Septiembre	/Julio a septiembre	/Abril a septiembre
7	|	/Octubre	/Septiembre	/Julio a septiembre	/Abril a septiembre
8	|	/Octubre	/Octubre	/Agosto a octubre	/Mayo a octubre
9	|	/Noviembre	/Octubre	/Agosto a octubre	/Mayo a octubre

*Los rubros a considerar sern:
*
Rubro				/Periodicidad	Nombre del deflactor
Alimentos y bebidas no alcohlicas		/Semanal	/d11wmes
Bebidas alcohlicas y tabaco		/Semanal	/d12wmes
Vestido y calzado			/Trimestral	/d2tmesini
Vivienda y servicios de conservacin		/Mensual	/d3mmes
Estimacin del alquiler			/No se deflactar /No se deflactar
Artculos y servicios de limpieza		/Mensual	/d42mmes
Cristalera, utensilios domsticos		/Trimestral	/d42tmesini
Enseres domsticos y muebles		/Semestral	/d41smesini
Cuidados de la salud			/Trimestral	/d51tmesini
Transporte pblico			/Semanal	/d611wmes
Transporte forneo			/Semestral	/d6smesini
Comunicaciones			/Mensual	/d6mmes
Educacin bsica			/Mensual	/d7mmes
Cuidado personal			/Mensual	/d23mmes
Accesorios personales			/Trimestral	/d23tmesini
Otros gastos y transferencias		/Semestral	/dINPCsmesini
Regalos otorgados			/Semestral	/dINPCsmesini

*Definicin de los deflactores

*Rubro 1.1 semanal, Alimentos.			
COMPUTE	d11w07	=	0.994115718	.
COMPUTE	d11w08	=	1.00000000	.
COMPUTE	d11w09	=	1.008539462	.
COMPUTE	d11w10	=	1.017879893	.
COMPUTE	d11w11	=	1.027182482	.

*Rubro 1.2 semanal, Bebidas alcoholicas y tabaco.			

COMPUTE	d12w07	=	0.9988975238	.
COMPUTE	d12w08	=	1.0000000000	.
COMPUTE	d12w09	=	1.0008319299	.
COMPUTE	d12w10	=	1.0039161577	.
COMPUTE	d12w11	=	1.0065742751	.

*Rubro 2 trimestral, Ropa calzado y accesorios.			

COMPUTE	d2t05	=	0.9952726703	.
COMPUTE	d2t06	=	0.9968658588	.
COMPUTE	d2t07	=	0.9995124669	.
COMPUTE	d2t08	=	1.0046228583	.

*Rubro 3 mensual, Vivienda.			

COMPUTE	d3m07	=	0.9973054926	.
COMPUTE	d3m08	=	1.0000000000	.
COMPUTE	d3m09	=	1.0021841272	.
COMPUTE	d3m10	=	1.0130222015	.
COMPUTE	d3m11	=	1.0322740442	.

*Rubro 4.2 mensual, Accesorios y artculos de limpieza para el hogar.			

COMPUTE	d42m07	=	0.9960392668	.
COMPUTE	d42m08	=	1.0000000000	.
COMPUTE	d42m09	=	1.0057375107	.
COMPUTE	d42m10	=	1.0139032841	.
COMPUTE	d42m11	=	1.0131185407	.

*Rubro 4.2 trimestral, Accesorios y artculos de limpieza para el hogar.			

COMPUTE	d42t05	=	0.9966784131	.
COMPUTE	d42t06	=	0.9970510429	.
COMPUTE	d42t07	=	1.0005922592	.
COMPUTE	d42t08	=	1.0065469316	.

*Rubro 4.1 semestral, Muebles y aparatos domsticos.			

COMPUTE	d41s02	=	1.0037887926	.
COMPUTE	d41s03	=	1.0033758915	.
COMPUTE	d41s04	=	1.0031300066	.
COMPUTE	d41s05	=	1.0029923729	.

*Rubro 5.1 trimestral, Salud.			

COMPUTE	d51t05	=	0.9935317420	.
COMPUTE	d51t06	=	0.9967807117	.
COMPUTE	d51t07	=	0.9998470267	.
COMPUTE	d51t08	=	1.0027284039	.

*Rubro 6.1.1 semanal, Transporte pblico urbano.			

COMPUTE	d611w07	=	0.9978493077	.
COMPUTE	d611w08	=	1.0000000000	.
COMPUTE	d611w09	=	1.0013008747	.
COMPUTE	d611w10	=	1.0017715429	.
COMPUTE	d611w11	=	1.0031639364	.

*Rubro 6 mensual, Transporte.			

COMPUTE	d6m07	=	0.9993636585	.
COMPUTE	d6m08	=	1.0000000000	.
COMPUTE	d6m09	=	1.0028528121	.
COMPUTE	d6m10	=	1.0046760378	.
COMPUTE	d6m11	=	1.0095165234	.

*Rubro 6 semestral, Transporte.			

COMPUTE	d6s02	=	0.9852485545	.
COMPUTE	d6s03	=	0.9901867555	.
COMPUTE	d6s04	=	0.9942550514	.
COMPUTE	d6s05	=	0.9978895864	.

*Rubro 7 mensual, Educacin y espacimiento.			

COMPUTE	d7m07	=	1.0014122584	.
COMPUTE	d7m08	=	1.0000000000	.
COMPUTE	d7m09	=	1.0135038803	.
COMPUTE	d7m10	=	1.0155617426	.
COMPUTE	d7m11	=	1.0157029684	.

*Rubro 2.3 mensual, Accesorios y cuidados del vestido.			

COMPUTE	d23m07	=	0.9959197302	.
COMPUTE	d23m08	=	1.0000000000	.
COMPUTE	d23m09	=	1.0102774717	.
COMPUTE	d23m10	=	1.0206951818	.
COMPUTE	d23m11	=	1.0331096197	.

*Rubro 2.3 trimestral, Accesorios y cuidados del vestido.			

COMPUTE	d23t05	=	0.9962046590	.
COMPUTE	d23t06	=	0.9979743341	.
COMPUTE	d23t07	=	1.0020657340	.
COMPUTE	d23t08	=	1.0103242178	.

*INPC semestral.			

COMPUTE	dINPCs02	=	0.9986800410	.
COMPUTE	dINPCs03	=	0.9990448597	.
COMPUTE	dINPCs04	=	0.9991027112	.
COMPUTE	dINPCs05	=	1.0007284568	.

EXECUTE.

*Una vez definidos los deflactores se seleccionan los 
rubros.

COMPUTE gasnomon = apo_tri/3 .
IF(SYSMIS(gasnomon)) gasnomon = 0.

IF (tipogasto ="2") 			esp = 1.
IF (tipogasto ="3" |  tipogasto ="4") 		reg = 1.

* Se elimina todo lo relacionado al autoconsumo.
SELECT IF ~(tipogasto="1").

*Control para la frecuencia de los regalos recibidos, se eliminan los siguientes cdigos:
* Cdigo 5-> Lo recibi slo una vez
* Cdigo 6 -> Otro.

*Para no monetario ENIGH (proyecto 2).
SELECT IF ~((("05"<=frecu & frecu<="06") | frecu="") & proyecto="2" & tipogasto="3").

*Para no monetario MCS (proyecto 1).
SELECT IF ~((("11"<=frecu & frecu<="12") | frecu="") & proyecto="1" & tipogasto="3").

*Gasto en Alimentos deflactado (semanal).

IF ( (clave >= 'A001' & clave < 'A223') 
| (clave >= 'A242' & clave < 'A248' ) ) ali_nm = gasnomon .

IF(decena = 	0	)	ali_nm=ali_nm/d11w08	.	
IF(decena = 	1	)	ali_nm=ali_nm/d11w08	.	
IF(decena = 	2	)	ali_nm=ali_nm/d11w08	.	
IF(decena = 	3	)	ali_nm=ali_nm/d11w09	.	
IF(decena = 	4	)	ali_nm=ali_nm/d11w09	.	
IF(decena = 	5	)	ali_nm=ali_nm/d11w09	.	
IF(decena = 	6	)	ali_nm=ali_nm/d11w10	.	
IF(decena = 	7	)	ali_nm=ali_nm/d11w10	.	
IF(decena = 	8	)	ali_nm=ali_nm/d11w10	.	
IF(decena = 	9	)	ali_nm=ali_nm/d11w11	.	
IF (SYSMIS(ali_nm)) ali_nm = 0.

*Gasto en Alcohol y tabaco deflactado (semanal).

IF ( (clave >= 'A223' & clave < 'A242')) alta_nm = gasnomon .

IF(decena = 	0	)	alta_nm=alta_nm/d12w08	.	
IF(decena = 	1	)	alta_nm=alta_nm/d12w08	.	
IF(decena = 	2	)	alta_nm=alta_nm/d12w08	.	
IF(decena = 	3	)	alta_nm=alta_nm/d12w09	.	
IF(decena = 	4	)	alta_nm=alta_nm/d12w09	.	
IF(decena = 	5	)	alta_nm=alta_nm/d12w09	.	
IF(decena = 	6	)	alta_nm=alta_nm/d12w10	.	
IF(decena = 	7	)	alta_nm=alta_nm/d12w10	.	
IF(decena = 	8	)	alta_nm=alta_nm/d12w10	.	
IF(decena = 	9	)	alta_nm=alta_nm/d12w11	.	
IF (SYSMIS(alta_nm)) alta_nm = 0.

*Gasto en Vestido y calzado deflactado (trimestral).

IF( (clave >= 'H001' & clave < 'H123') 
| (clave = 'H136') ) veca_nm = gasnomon .

IF(decena = 	0	)	veca_nm=veca_nm/d2t05	.	
IF(decena = 	1	)	veca_nm=veca_nm/d2t05	.	
IF(decena = 	2	)	veca_nm=veca_nm/d2t06	.	
IF(decena = 	3	)	veca_nm=veca_nm/d2t06	.	
IF(decena = 	4	)	veca_nm=veca_nm/d2t06	.	
IF(decena = 	5	)	veca_nm=veca_nm/d2t07	.	
IF(decena = 	6	)	veca_nm=veca_nm/d2t07	.	
IF(decena = 	7	)	veca_nm=veca_nm/d2t07	.	
IF(decena = 	8	)	veca_nm=veca_nm/d2t08	.	
IF(decena = 	9	)	veca_nm=veca_nm/d2t08	.	
IF (SYSMIS(veca_nm)) veca_nm = 0.

*Gasto en Vivienda y servicios de conservacin deflactado (mensual).
IF( (clave >= 'G001' & clave < 'G017') 
| (clave >= 'R001' & clave < 'R005')
| (clave >= 'R013' & clave < 'R014')) viv_nm = gasnomon .
IF(decena = 	0	)	viv_nm=viv_nm/d3m07	.	
IF(decena = 	1	)	viv_nm=viv_nm/d3m07	.	
IF(decena = 	2	)	viv_nm=viv_nm/d3m08	.	
IF(decena = 	3	)	viv_nm=viv_nm/d3m08	.	
IF(decena = 	4	)	viv_nm=viv_nm/d3m08	.	
IF(decena = 	5	)	viv_nm=viv_nm/d3m09	.	
IF(decena = 	6	)	viv_nm=viv_nm/d3m09	.	
IF(decena = 	7	)	viv_nm=viv_nm/d3m09	.	
IF(decena = 	8	)	viv_nm=viv_nm/d3m10	.	
IF(decena = 	9	)	viv_nm=viv_nm/d3m10	.	
IF (SYSMIS(viv_nm)) viv_nm = 0.

*Gasto en Artculos de limpieza deflactado (mensual).

IF( clave >= 'C001' & clave < 'C025' ) lim_nm = gasnomon .

IF(decena = 	0	)	lim_nm=lim_nm/d42m07	.	
IF(decena = 	1	)	lim_nm=lim_nm/d42m07	.	
IF(decena = 	2	)	lim_nm=lim_nm/d42m08	.	
IF(decena = 	3	)	lim_nm=lim_nm/d42m08	.	
IF(decena = 	4	)	lim_nm=lim_nm/d42m08	.	
IF(decena = 	5	)	lim_nm=lim_nm/d42m09	.	
IF(decena = 	6	)	lim_nm=lim_nm/d42m09	.	
IF(decena = 	7	)	lim_nm=lim_nm/d42m09	.	
IF(decena = 	8	)	lim_nm=lim_nm/d42m10	.	
IF(decena = 	9	)	lim_nm=lim_nm/d42m10	.	
IF (SYSMIS(lim_nm)) lim_nm = 0.

*Gasto en Cristalera y blancos deflactado(trimestral).

IF(clave >= 'I001' & clave < 'I027') cris_nm = gasnomon .

IF(decena = 	0	)	cris_nm=cris_nm/d42t05	.	
IF(decena = 	1	)	cris_nm=cris_nm/d42t05	.	
IF(decena = 	2	)	cris_nm=cris_nm/d42t06	.	
IF(decena = 	3	)	cris_nm=cris_nm/d42t06	.	
IF(decena = 	4	)	cris_nm=cris_nm/d42t06	.	
IF(decena = 	5	)	cris_nm=cris_nm/d42t07	.	
IF(decena = 	6	)	cris_nm=cris_nm/d42t07	.	
IF(decena = 	7	)	cris_nm=cris_nm/d42t07	.	
IF(decena = 	8	)	cris_nm=cris_nm/d42t08	.	
IF(decena = 	9	)	cris_nm=cris_nm/d42t08	.	
IF (SYSMIS(cris_nm)) cris_nm = 0.

*Gasto en Enseres domsticos y muebles deflactado (semestral).

IF(clave >= 'K001' & clave < 'K038') ens_nm = gasnomon .

IF(decena = 	0	)	ens_nm=ens_nm/d41s02	.	
IF(decena = 	1	)	ens_nm=ens_nm/d41s02	.	
IF(decena = 	2	)	ens_nm=ens_nm/d41s03	.	
IF(decena = 	3	)	ens_nm=ens_nm/d41s03	.	
IF(decena = 	4	)	ens_nm=ens_nm/d41s03	.	
IF(decena = 	5	)	ens_nm=ens_nm/d41s04	.	
IF(decena = 	6	)	ens_nm=ens_nm/d41s04	.	
IF(decena = 	7	)	ens_nm=ens_nm/d41s04	.	
IF(decena = 	8	)	ens_nm=ens_nm/d41s05	.	
IF(decena = 	9	)	ens_nm=ens_nm/d41s05	.	
IF (SYSMIS(ens_nm)) ens_nm = 0.

*Gasto en Salud deflactado (trimestral).

IF(clave >= 'J001' & clave < 'J073') sal_nm = gasnomon. 

IF(decena = 	0	)	sal_nm=sal_nm/d51t05	.	
IF(decena = 	1	)	sal_nm=sal_nm/d51t05	.	
IF(decena = 	2	)	sal_nm=sal_nm/d51t06	.	
IF(decena = 	3	)	sal_nm=sal_nm/d51t06	.	
IF(decena = 	4	)	sal_nm=sal_nm/d51t06	.	
IF(decena = 	5	)	sal_nm=sal_nm/d51t07	.	
IF(decena = 	6	)	sal_nm=sal_nm/d51t07	.	
IF(decena = 	7	)	sal_nm=sal_nm/d51t07	.	
IF(decena = 	8	)	sal_nm=sal_nm/d51t08	.	
IF(decena = 	9	)	sal_nm=sal_nm/d51t08	.	
IF (SYSMIS(sal_nm)) sal_nm = 0.

*Gasto en Transporte pblico deflactado (semanal).

IF(clave >= 'B001' & clave < 'B008') tpub_nm = gasnomon .

IF(decena = 	0	)	tpub_nm=tpub_nm/d611w08	.	
IF(decena = 	1	)	tpub_nm=tpub_nm/d611w08	.	
IF(decena = 	2	)	tpub_nm=tpub_nm/d611w08	.	
IF(decena = 	3	)	tpub_nm=tpub_nm/d611w09	.	
IF(decena = 	4	)	tpub_nm=tpub_nm/d611w09	.	
IF(decena = 	5	)	tpub_nm=tpub_nm/d611w09	.	
IF(decena = 	6	)	tpub_nm=tpub_nm/d611w10	.	
IF(decena = 	7	)	tpub_nm=tpub_nm/d611w10	.	
IF(decena = 	8	)	tpub_nm=tpub_nm/d611w10	.	
IF(decena = 	9	)	tpub_nm=tpub_nm/d611w11	.	
IF (SYSMIS(tpub_nm)) tpub_nm = 0.

*Gasto en Transporte forneo deflactado (semestral).

IF((clave >= 'M001' & clave < 'M019') 
| (clave >= 'F007' & clave < 'F015')) tfor_nm = gasnomon .

IF(decena = 	0	)	tfor_nm=tfor_nm/d6s02	.	
IF(decena = 	1	)	tfor_nm=tfor_nm/d6s02	.	
IF(decena = 	2	)	tfor_nm=tfor_nm/d6s03	.	
IF(decena = 	3	)	tfor_nm=tfor_nm/d6s03	.	
IF(decena = 	4	)	tfor_nm=tfor_nm/d6s03	.	
IF(decena = 	5	)	tfor_nm=tfor_nm/d6s04	.	
IF(decena = 	6	)	tfor_nm=tfor_nm/d6s04	.	
IF(decena = 	7	)	tfor_nm=tfor_nm/d6s04	.	
IF(decena = 	8	)	tfor_nm=tfor_nm/d6s05	.	
IF(decena = 	9	)	tfor_nm=tfor_nm/d6s05	.	
IF (SYSMIS(tfor_nm)) tfor_nm = 0.

*Gasto en Comunicaciones deflactado (mensual).

IF((clave >= 'F001' & clave < 'F007')
| (clave >= 'R005' & clave < 'R009')
| (clave >= 'R010' & clave < 'R012'))  com_nm = gasnomon .

IF(decena = 	0	)	com_nm=com_nm/d6m07	.	
IF(decena = 	1	)	com_nm=com_nm/d6m07	.	
IF(decena = 	2	)	com_nm=com_nm/d6m08	.	
IF(decena = 	3	)	com_nm=com_nm/d6m08	.	
IF(decena = 	4	)	com_nm=com_nm/d6m08	.	
IF(decena = 	5	)	com_nm=com_nm/d6m09	.	
IF(decena = 	6	)	com_nm=com_nm/d6m09	.	
IF(decena = 	7	)	com_nm=com_nm/d6m09	.	
IF(decena = 	8	)	com_nm=com_nm/d6m10	.	
IF(decena = 	9	)	com_nm=com_nm/d6m10	.	
IF (SYSMIS(com_nm)) com_nm = 0.

*Gasto en Educacin y recreacin deflactado (mensual).

IF(( clave >= 'E001' & clave < 'E035') 
| (clave >= 'H134' & clave < 'H136') 
| (clave >= 'L001' & clave < 'L030')  
| (clave >= 'N003' & clave < 'N006')
| (clave >= 'R009' & clave < 'R010') ) 
edre_nm = gasnomon .

IF(decena = 	0	)	edre_nm=edre_nm/d7m07	.	
IF(decena = 	1	)	edre_nm=edre_nm/d7m07	.	
IF(decena = 	2	)	edre_nm=edre_nm/d7m08	.	
IF(decena = 	3	)	edre_nm=edre_nm/d7m08	.	
IF(decena = 	4	)	edre_nm=edre_nm/d7m08	.	
IF(decena = 	5	)	edre_nm=edre_nm/d7m09	.	
IF(decena = 	6	)	edre_nm=edre_nm/d7m09	.	
IF(decena = 	7	)	edre_nm=edre_nm/d7m09	.	
IF(decena = 	8	)	edre_nm=edre_nm/d7m10	.	
IF(decena = 	9	)	edre_nm=edre_nm/d7m10	.	
IF (SYSMIS(edre_nm)) edre_nm = 0.

*Gasto en Educacin bsica deflactado (mensual).

IF((clave >= 'E002' & clave < 'E004') 
|   (clave >= 'H134' & clave < 'H136')) edba_nm = gasnomon .

IF(decena = 	0	)	edba_nm=edba_nm/d7m07	.	
IF(decena = 	1	)	edba_nm=edba_nm/d7m07	.	
IF(decena = 	2	)	edba_nm=edba_nm/d7m08	.	
IF(decena = 	3	)	edba_nm=edba_nm/d7m08	.	
IF(decena = 	4	)	edba_nm=edba_nm/d7m08	.	
IF(decena = 	5	)	edba_nm=edba_nm/d7m09	.	
IF(decena = 	6	)	edba_nm=edba_nm/d7m09	.	
IF(decena = 	7	)	edba_nm=edba_nm/d7m09	.	
IF(decena = 	8	)	edba_nm=edba_nm/d7m10	.	
IF(decena = 	9	)	edba_nm=edba_nm/d7m10	.	
IF (SYSMIS(edba_nm)) edba_nm = 0.

*Gasto en Cuidado personal deflactado (mensual).

IF( (clave >= 'D001' & clave < 'D027') 
| (clave >= 'H132' & clave < 'H133' )) cuip_nm = gasnomon .

IF(decena = 	0	)	cuip_nm=cuip_nm/d23m07	.	
IF(decena = 	1	)	cuip_nm=cuip_nm/d23m07	.	
IF(decena = 	2	)	cuip_nm=cuip_nm/d23m08	.	
IF(decena = 	3	)	cuip_nm=cuip_nm/d23m08	.	
IF(decena = 	4	)	cuip_nm=cuip_nm/d23m08	.	
IF(decena = 	5	)	cuip_nm=cuip_nm/d23m09	.	
IF(decena = 	6	)	cuip_nm=cuip_nm/d23m09	.	
IF(decena = 	7	)	cuip_nm=cuip_nm/d23m09	.	
IF(decena = 	8	)	cuip_nm=cuip_nm/d23m10	.	
IF(decena = 	9	)	cuip_nm=cuip_nm/d23m10	.	
IF (SYSMIS(cuip_nm)) cuip_nm = 0.

*Gasto en Accesorios personales deflactado (trimestral).

IF((clave >= 'H123' & clave < 'H132') 
| (clave >= 'H133' & clave < 'H134' )) accp_nm = gasnomon .

IF(decena = 	0	)	accp_nm=accp_nm/d23t05	.	
IF(decena = 	1	)	accp_nm=accp_nm/d23t05	.	
IF(decena = 	2	)	accp_nm=accp_nm/d23t06	.	
IF(decena = 	3	)	accp_nm=accp_nm/d23t06	.	
IF(decena = 	4	)	accp_nm=accp_nm/d23t06	.	
IF(decena = 	5	)	accp_nm=accp_nm/d23t07	.	
IF(decena = 	6	)	accp_nm=accp_nm/d23t07	.	
IF(decena = 	7	)	accp_nm=accp_nm/d23t07	.	
IF(decena = 	8	)	accp_nm=accp_nm/d23t08	.	
IF(decena = 	9	)	accp_nm=accp_nm/d23t08	.	
IF (SYSMIS(accp_nm)) accp_nm = 0.

* Gasto en Otros gastos y transferencias deflactado (semestral).

IF((clave >= 'N001' & clave < 'N003') 
|   (clave >= 'N006' & clave < 'N017') 
|   (clave >= 'T901' & clave < 'T916')
| (clave >= 'R012' & clave < 'R013')) otr_nm = gasnomon .

IF(decena = 	0	)	otr_nm=otr_nm/dINPCs02	.	
IF(decena = 	1	)	otr_nm=otr_nm/dINPCs02	.	
IF(decena = 	2	)	otr_nm=otr_nm/dINPCs03	.	
IF(decena = 	3	)	otr_nm=otr_nm/dINPCs03	.	
IF(decena = 	4	)	otr_nm=otr_nm/dINPCs03	.	
IF(decena = 	5	)	otr_nm=otr_nm/dINPCs04	.	
IF(decena = 	6	)	otr_nm=otr_nm/dINPCs04	.	
IF(decena = 	7	)	otr_nm=otr_nm/dINPCs04	.	
IF(decena = 	8	)	otr_nm=otr_nm/dINPCs05	.	
IF(decena = 	9	)	otr_nm=otr_nm/dINPCs05	.	
IF (SYSMIS(otr_nm)) otr_nm = 0.

*Gasto en Regalos otorgados deflactado.

IF( (clave >= 'T901' & clave < 'T916' )
| (clave >= 'N013' & clave < 'N014' ))  reda_nm = gasnomon .

IF(decena = 	1	)	reda_nm=reda_nm/dINPCs02	.	
IF(decena = 	2	)	reda_nm=reda_nm/dINPCs03	.	
IF(decena = 	3	)	reda_nm=reda_nm/dINPCs03	.	
IF(decena = 	4	)	reda_nm=reda_nm/dINPCs03	.	
IF(decena = 	5	)	reda_nm=reda_nm/dINPCs04	.	
IF(decena = 	6	)	reda_nm=reda_nm/dINPCs04	.	
IF(decena = 	7	)	reda_nm=reda_nm/dINPCs04	.	
IF(decena = 	8	)	reda_nm=reda_nm/dINPCs05	.	
IF(decena = 	9	)	reda_nm=reda_nm/dINPCs05	.	
IF (SYSMIS(reda_nm)) reda_nm = 0.

SORT CASES by proyecto(A) folioviv (A) foliohog (A) numren(A).

SAVE OUTFILE=
    'C:\Medicion\2010\SPSS\Bases\ingresonomonetario_def10.sav'
  /COMPRESSED.

*Construccin de la base de pagos en especie a partir de la base de gasto no monetario

GET
  FILE='C:\Medicion\2010\SPSS\Bases\ingresonomonetario_def10.sav'.

FILTER OFF.
USE ALL.
SELECT IF(esp = 1).

SORT CASES by proyecto(A) folioviv (A) foliohog (A).

AGGREGATE
  /OUTFILE='C:\Medicion\2010\SPSS\Bases\esp_def10.sav'  
  /BREAK=proyecto folioviv foliohog
 /ali_nme = SUM(ali_nm) 
 /alta_nme = SUM(alta_nm)
 /veca_nme = SUM(veca_nm) 
 /viv_nme = SUM(viv_nm) 
 /lim_nme =  SUM(lim_nm) 
 /cris_nme = SUM(cris_nm) 
 /ens_nme = SUM(ens_nm) 
 /sal_nme =  SUM(sal_nm) 
 /tpub_nme = SUM(tpub_nm) 
 /tfor_nme =  SUM(tfor_nm) 
 /com_nme = SUM(com_nm)
 /edre_nme = SUM(edre_nm) 
 /edba_nme = SUM(edba_nm)
 /cuip_nme = SUM(cuip_nm) 
 /accp_nme = SUM(accp_nm) 
 /otr_nme = SUM(otr_nm)
 /reda_nme =  SUM(reda_nm).
EXECUTE .

*Construccin de base de regalos a partir de la base no monetaria .

GET
 FILE='C:\Medicion\2010\SPSS\Bases\ingresonomonetario_def10.sav'.

FILTER OFF.
USE ALL.

SELECT IF(reg = 1).

SORT CASES by proyecto(A) folioviv (A) foliohog (A) numren(A).

AGGREGATE
  /OUTFILE='C:\Medicion\2010\SPSS\Bases\reg_def10.sav'
 /BREAK=proyecto folioviv foliohog
 /ali_nmr = SUM(ali_nm) 
 /alta_nmr = SUM(alta_nm)
 /veca_nmr = SUM(veca_nm) 
 /viv_nmr = SUM(viv_nm)
 /lim_nmr =  SUM(lim_nm) 
 /cris_nmr = SUM(cris_nm) 
 /ens_nmr = SUM(ens_nm) 
 /sal_nmr =  SUM(sal_nm) 
 /tpub_nmr = SUM(tpub_nm) 
 /tfor_nmr =  SUM(tfor_nm) 
 /com_nmr = SUM(com_nm) 
 /edre_nmr = SUM(edre_nm) 
 /edba_nmr = SUM(edba_nm) 
 /cuip_nmr = SUM(cuip_nm) 
 /accp_nmr = SUM(accp_nm)
 /otr_nmr = SUM(otr_nm)
 /reda_nmr =  SUM(reda_nm).
EXECUTE .

***********************************************************
*Parte VII.3
*
*Construccin del  ingreso corriente total
*
***********************************************************.

GET
  FILE='C:\Medicion\2010\SPSS\MCS\concentrado.sav'.

SORT CASES by proyecto(A) folioviv (A) foliohog (A).

SAVE OUTFILE='C:\Medicion\2010\SPSS\Bases\concentr_10.sav'
 /KEEP = proyecto folioviv foliohog tam_loc factor tam_hog est_dis upm ubica_geo
 /COMPRESSED.

GET
  FILE='C:\Medicion\2010\SPSS\Bases\concentr_10.sav'.

*Incorporacin de la base de ingreso monetario deflactado.

MATCH FILES /FILE=*
 /TABLE= 'C:\Medicion\2010\SPSS\Bases\ingreso_deflactado10.sav'
 /BY proyecto folioviv foliohog.

*Incorporacin de la base de ingreso no monetario deflactado: pago en especie.

MATCH FILES /FILE=*
 /TABLE= 'C:\Medicion\2010\SPSS\Bases\esp_def10.sav'
 /BY proyecto folioviv foliohog.

*Incorporacin de la base de ingreso no monetario deflactado: regalos en especie.

MATCH FILES /FILE=*
 /TABLE= 'C:\Medicion\2010\SPSS\Bases\reg_def10.sav' 
/BY proyecto folioviv foliohog.
EXECUTE .

*Construccin del indicador del tamao de la localidad 
(rural para hogares en localidades con menos de 2,500 
habitantes y urbano en caso contrario).

IF (tam_loc = 4 ) rururb = 1 .
IF (tam_loc < 4) rururb = 0 .
value labels rururb 1 'Rural <2500 hab.' 0 'Urbano' .
FORMATS rururb (F1).

*Se calculan los gastos totales.

COMPUTE pago_esp = SUM(ali_nme, alta_nme, veca_nme, viv_nme, 
lim_nme, ens_nme, cris_nme, sal_nme, tpub_nme, tfor_nme, 
com_nme, edre_nme, cuip_nme, accp_nme, otr_nme) .
IF (SYSMIS(pago_esp)) pago_esp=0.

COMPUTE reg_esp = SUM(ali_nmr, alta_nmr, veca_nmr, viv_nmr, 
lim_nmr, ens_nmr, cris_nmr, sal_nmr, tpub_nmr, tfor_nmr, 
com_nmr, edre_nmr, cuip_nmr, accp_nmr, otr_nmr) .
IF (SYSMIS(reg_esp)) reg_esp=0.

COMPUTE nomon = SUM(pago_esp, reg_esp) .
IF (SYSMIS(nomon)) nomon=0.

COMPUTE ict = SUM(ing_mon, nomon) .
variable label ict 'Ingreso corriente total'.

SORT CASES by proyecto(A) folioviv (A) foliohog (A).

SAVE OUTFILE=
    'C:\Medicion\2010\SPSS\Bases\ingresostot10.sav'
  /COMPRESSED.

***********************************************************
*Parte VII.4
*
*Construccin del tamao de hogar con economas de escala
*y escalas de equivalencia
*
***********************************************************.

GET
  FILE='C:\Medicion\2010\SPSS\MCS\poblacion.sav'.

SORT CASES by proyecto(A) folioviv (A) foliohog (A) numren(A).

* Poblacin objeto: no se incluye a huspedes ni trabajadores domsticos.

COMPUTE par=NUMBER(parentesco,F3).
EXECUTE.
DELETE VARIABLES parentesco.

RENAME VARIABLES (par=parentesco).

SELECT IF  ~(400<=parentesco & parentesco<500). 
SELECT IF  ~(700<=parentesco & parentesco<800). 

*Total de integrantes del hogar.
COMPUTE ind=1.

AGGREGATE
  /OUTFILE=* MODE=ADDVARIABLES
  /BREAK=proyecto folioviv foliohog
  /tot_ind=SUM(ind)
  /N_BREAK=N.

*************************
*Escalas de equivalencia*
*************************.

COMPUTE n_05=0.
IF (edad>=0 & edad<=5)		n_05=1.
IF SYSMIS(edad)             n_05=9.
RECODE n_05 (9=SYSMIS).

COMPUTE n_6_12=0.
IF (edad>=6 & edad<=12)	n_6_12=1.
IF SYSMIS(edad)             n_6_12=9.
RECODE n_6_12 (9=SYSMIS).

COMPUTE n_13_18=0.
IF (edad>=13 & edad<=18)	n_13_18=1.
IF SYSMIS(edad)             n_13_18=9.
RECODE n_13_18 (9=SYSMIS).

COMPUTE n_19=0.
IF (edad>=19)		n_19=1.
IF SYSMIS(edad)             n_19=9.
RECODE n_19 (9=SYSMIS).

COMPUTE 				                  tamhoges=-1.
IF n_05=1 				                   tamhoges=n_05*.7031.
IF n_6_12=1			                  tamhoges=n_6_12*.7382.
IF n_13_18=1                 		tamhoges=n_13_18*.7057.
IF n_19=1                        tamhoges=n_19*.9945.
IF tot_ind=1                     tamhoges=1.


SORT CASES by proyecto(A) folioviv (A) foliohog (A).

AGGREGATE
  /OUTFILE='C:\Medicion\2010\SPSS\Bases\tamhogesc10.sav'
  /BREAK=proyecto folioviv foliohog
  /tamhogesc=SUM(tamhoges)
  /N_BREAK2=N.
EXECUTE.

*******************************************************
Parte VII.5

*Bienestar por ingresos

*******************************************************.

GET
  FILE='C:\Medicion\2010\SPSS\Bases\ingresostot10.sav'.

*Incorporacin de la informacin sobre el tamao del hogar ajustado*.

MATCH FILES /FILE=*
  /FILE='C:\Medicion\2010\SPSS\Bases\tamhogesc10.sav'
  /IN merge_ing
  /BY proyecto folioviv foliohog.
EXECUTE.


DELETE VARIABLES merge_ing.
desc  ict tamhogesc.

*Informacin per capita.

COMPUTE ictpc = ict / tamhogesc .
VARIABLE LABELS  ictpc 'Ingreso corriente total per capita'.

*Generacin del factor de expansin para personas.

VARIABLE LABELS  factor 'Factor de expansin para hogares'.

COMPUTE factorp= factor*tam_hog.
VARIABLE LABELS factorp 'Factor de expansin para personas'.

**************************************************************

*Indicador de Bienestar por ingresos

**************************************************************
*
	LP I: Valor de la Canasta para bienestar mnimo
*
LP II: Valor de la Canasta Alimentaria ms el valor de la canasta
no alimentaria (ver Nota Tcnica)..
*
En este programa se construyen los indicadores de bienestar por ingresos
mediante las 2 lneas definidas por CONEVAL, denominndoles:
*
lp1 : Lnea de Bienestar Mnimo
lp2 : Lnea de Bienestar
************************************************************
*
*Bienestar mnimo
*
************************************************************

*Valor de la canasta bsica (ver Nota Tcnica).

COMPUTE lp1_urb = 978.47.
COMPUTE lp1_rur = 683.82.

* Se identifican los hogares bajo LP1.

IF (ictpc <= lp1_urb & rururb = 0) 	plb_m = 1 .
IF (ictpc > lp1_urb & rururb = 0) 	plb_m = 0 .
IF (ictpc <= lp1_rur & rururb = 1) 	plb_m = 1 .
IF (ictpc > lp1_rur & rururb = 1) 	plb_m = 0 .

**********************************************

**********************************************

*Bienestar

**********************************************.

COMPUTE lp2_urb = 2113.86.
COMPUTE lp2_rur = 1328.51.

*Se identifica a los hogares bajo LP2.

IF(ictpc <= (lp2_urb) & rururb = 0) plb = 1 . 
IF(ictpc > (lp2_urb)  & rururb = 0) plb = 0 . 
IF(ictpc <= (lp2_rur)  & rururb = 1) plb = 1 . 
IF(ictpc > (lp2_rur) & rururb = 1) plb = 0 . 

VARIABLE LABELS  factor 	"Factor de expansin a nivel hogar".
VARIABLE LABELS factorp 	"Factor de expansin para personas".
VARIABLE LABELS tam_loc 	"Tamao de la localidad".
VARIABLE LABELS rururb 	"Identificador de localidades rurales".
VARIABLE LABELS tam_hog 	"Total de integrantes del hogar".
VARIABLE LABELS tamhogesc 	"Tamao de hogar ajustado".
VARIABLE LABELS ict 	"Ingreso corriente total del hogar".
VARIABLE LABELS ictpc 	"Ingreso corriente total per cpita".
VARIABLE LABELS plb_m 	"Identificador de los hogares con ingreso inferior a la lnea de bienestar mnimo".
VARIABLE LABELS plb 	"Identificador de los hogarescon ingreso inferior a la lnea de bienestar".

SAVE OUTFILE='C:\Medicion\2010\SPSS\Bases\p_ingresos10.sav'
 /KEEP = proyecto folioviv foliohog factor tam_loc 
rururb tamhogesc ict ictpc plb_m plb est_dis upm ubica_geo tam_hog
lp1_rur lp1_urb lp2_rur lp2_urb 
  /COMPRESSED.

*********************************************************
*
Parte VIII Pobreza 
*
*********************************************************.
**********************************************
*
Integracin de las bases
*
**********************************************.

GET
  FILE='C:\Medicion\2010\SPSS\Bases\IC_REZEDU10.sav'.

MATCH FILES /FILE=*
  /FILE='C:\Medicion\2010\SPSS\Bases\IC_ASALUD10.sav'
  /IN merge1
  /BY proyecto folioviv foliohog numren.
EXECUTE.

fre merge1.
DELETE VARIABLES merge1.

SORT CASES by proyecto(A) folioviv (A) foliohog (A) numren(A).

MATCH FILES /FILE=*
  /FILE='C:\Medicion\2010\SPSS\Bases\IC_SEGSOC10.sav'
  /IN merge2
  /BY proyecto folioviv foliohog numren.
EXECUTE.

SORT CASES by proyecto(A) folioviv (A) foliohog (A) numren(A).

fre merge2.
DELETE VARIABLES merge2.

MATCH FILES /FILE=*
  /TABLE='C:\Medicion\2010\SPSS\Bases\IC_CEV10.sav'
  /BY proyecto folioviv foliohog.
EXECUTE.

SORT CASES by proyecto(A) folioviv (A) foliohog (A) numren(A).

MATCH FILES /FILE=*
  /TABLE='C:\Medicion\2010\SPSS\Bases\IC_SBV10.sav'
  /BY proyecto folioviv foliohog.
EXECUTE.

SORT CASES by proyecto(A) folioviv (A) foliohog (A) numren(A).

MATCH FILES /FILE=*
  /TABLE='C:\Medicion\2010\SPSS\Bases\IC_ALI10.sav'
  /BY proyecto folioviv foliohog.
EXECUTE.

SORT CASES by proyecto(A) folioviv (A) foliohog (A) numren(A).

MATCH FILES /FILE=*
  /TABLE='C:\Medicion\2010\SPSS\Bases\p_ingresos10.sav'
  /BY proyecto folioviv foliohog.
EXECUTE.

VALIDATEDATA ID= proyecto folioviv foliohog  numren.

COMPUTE ent=NUMBER(SUBSTR(folioviv,1,2),F2).
VARIABLE LABELS ent "Identificador de la entidad federativa".
VALUE LABELS  ent
1	"Aguascalientes"
2	"Baja California"
3	"Baja California Sur"
4	"Campeche"
5	"Coahuila"
6	"Colima"
7	"Chiapas"
8	"Chihuahua"
9	"Distrito Federal"
10	"Durango"
11	"Guanajuato"
12	"Guerrero"
13	"Hidalgo"
14	"Jalisco"
15	"Mxico"
16	"Michoacn"
17	"Morelos"
18	"Nayarit"
19	"Nuevo Len"
20	"Oaxaca"
21	"Puebla"
22	"Quertaro"
23	"Quintana Roo"
24	"San Luis Potos"
25	"Sinaloa"
26	"Sonora"
27	"Tabasco"
28	"Tamaulipas"
29	"Tlaxcala"
30	"Veracruz"
31	"Yucatn"
32	"Zacatecas".
FORMATS ent (F2).

****************************
*ndice de Privacin Social
****************************.
*Este ndice se construye para cada persona a partir de la suma 
de los seis indicadores asociados a las carencias sociales.

COMPUTE i_privacion=SUM.6(ic_rezedu, ic_asalud ,ic_segsoc ,ic_cv, ic_sbv ,ic_ali).
IF sysmiss(ic_rezedu) | sysmiss (ic_asalud) | sysmiss (ic_segsoc) | sysmiss (ic_cv) | sysmiss (ic_sbv) | sysmiss (ic_ali) i_privacion=9.
RECODE i_privacion (9=sysmiss).
VARIABLE LABELS  i_privacion "ndice de Privacin Social".
FORMATS i_privacion (F1).

****************************
*Pobreza 
****************************.
*Una persona se encuentra en situacin de pobreza  
cuando presenta al menos una carencia social y su ingreso es
inferior a la lnea de bienestar.

COMPUTE pobreza=-1.
IF plb=1 & (i_privacion>=1 &  ~sysmiss(i_privacion))  pobreza=1.
IF (plb=0 | i_privacion=0) & (~sysmiss(plb) & ~sysmiss(i_privacion))  pobreza=0.
IF (sysmiss(plb) | sysmiss(i_privacion))			pobreza=9.
RECODE pobreza (9=sysmiss).
VARIABLE LABELS pobreza "Pobreza ".
VALUE LABELS pobreza 0 "No pobre " 
	1 "Pobreza ".
FORMATS pobreza (F9).

*Una persona se encuentra en situacin de pobreza  extrema
cuando presenta al menos tres carencias sociales y su ingreso es inferior 
a la lnea de bienestar mnimo.

COMPUTE pobreza_e=-1.
IF plb_m=1 & (i_privacion>=3 &  ~sysmiss(i_privacion))  pobreza_e=1.
IF (plb_m=0 | i_privacion<3) & (~sysmiss(plb_m) & ~sysmiss(i_privacion))  pobreza_e=0.
IF (sysmiss(plb_m) | sysmiss(i_privacion))				pobreza_e=9.
RECODE pobreza_e (9=sysmiss).
VARIABLE LABELS pobreza_e "Pobreza  extrema".
VALUE LABELS pobreza_e 0 "No pobre  extremo" 
	1 "Pobreza  extrema".
FORMATS pobreza_e (F9).

*Una persona se encuentra en situacin de pobreza  moderada
cuando presenta menos de tres carencias sociales, y su ingreso es superior a la
lnea de bienestar mnimo, pero inferior a la lnea de bienestar.

COMPUTE pobreza_m=1.
IF pobreza=1 & pobreza_e=0 pobreza_m=1.
IF pobreza=0 | (pobreza=1 & pobreza_e=1) pobreza_m=0. 
IF SYSMISS(pobreza)         pobreza_m=9.
RECODE pobreza_m (9=SYSMIS).
VARIABLE LABELS pobreza_m "Pobreza  moderada".
VALUE LABELS pobreza_m 0 "No pobre  moderado" 
	1 "Pobre  moderado".
FORMATS pobreza_m (F9).

*******************************
*Poblacin vulnerable
*******************************.

*Existen dos grupos de poblacin vulnerable:
*
Vulnerables por carencias sociales.- Poblacin que presenta una o ms 
carencias sociales y cuyo ingreso es superior a la lnea de bienestar.

COMPUTE vul_car=0.
IF (i_privacion>=1 & plb=0) vul_car=1.
IF SYSMISS(pobreza)         vul_car=9.
RECODE vul_car (9=SYSMIS).
VARIABLE LABELS vul_car "Poblacin vulnerable por carencias".
VALUE LABELS vul_car 0"No vulnerable" 1"Vulnerables".
FORMATS vul_car (F1).

*Vulnerables por ingresos.- Poblacin que no presenta carencias sociales y 
cuyo ingreso es inferior o igual a la lnea de bienestar.

COMPUTE vul_ing=0.
IF (i_privacion=0 & plb=1) vul_ing=1.
IF SYSMISS(pobreza)         vul_ing=9.
RECODE vul_ing (9=SYSMIS).
VARIABLE LABELS vul_ing "Poblacin vulnerable por ingresos".
VALUE LABELS vul_ing 0"No vulnerable" 1"Vulnerables".
FORMATS vul_ing (F1).

***********************************************
*Poblacin no pobre  
*y no vulnerable
************************************************.
* Se considera poblacin no pobre  y no vulnerable aquella 
cuyo ingreso es superior a la lnea de bienestar y que no tiene carencia social 
alguna.

COMPUTE no_pobv=0.
IF (i_privacion=0 & plb=0) no_pobv=1.
IF SYSMISS(pobreza)         no_pobv=9.
RECODE no_pobv (9=SYSMIS).
VARIABLE LABELS no_pobv "Poblacin no pobre  y no vulnerable".
VALUE LABELS no_pobv 0"Pobre  o vulnerable"
1"No pobre  y no vulnerable".
FORMATS no_pobv (F1).

*****************************
*Poblacin carenciada 
****************************.
* Se considera poblacin carenciada aquella que presenta al menos una carencia 
social.

COMPUTE carencias=0.
IF (i_privacion>0 ) carencias=1.
IF SYSMISS(pobreza)         carencias=9.
RECODE carencias (9=SYSMIS).
VARIABLE LABELS carencias "Poblacin con al menos una carencia".
VALUE LABELS carencias  0"Poblacin sin carencias"
 1" Poblacin carenciada".
FORMATS carencias (F1).

*****************************
*Poblacin con tres o ms carencias 
****************************.
* Se considera poblacin carenciada aquella que presenta al menos tres carencias 
sociales.

COMPUTE carencias3=0.
IF (i_privacion>2 ) carencias3=1.
IF SYSMISS(pobreza)         carencias3=9.
RECODE carencias3 (9=SYSMIS).
VARIABLE LABELS carencias3 "Poblacin con al menos tres carencia".
VALUE LABELS carencias3  0"Poblacin con menos de tres carencias"
 1" Poblacin con al menos tres carencias".
FORMATS carencias3 (F1).

*******************************
*Cuadrantes
*******************************.
*A partir de la lnea de bienestar y el umbral de privacin es posible 
categorizar a la poblacin en cuatro grupos o cuadrantes:
*
1. Poblacin pobre 
2. Poblacin vulnerable por carencias
3. Poblacin vulnerable por ingresos
4. Poblacin no pobre  y no vulnerable.

COMPUTE cuadrantes=-1.
IF plb=1 & (i_privacion>=1)     cuadrantes=1.
IF plb=0 & (i_privacion>=1)     cuadrantes=2.
IF plb=1 & (i_privacion=0)     cuadrantes=3.
IF plb=0 & (i_privacion=0)     cuadrantes=4.
IF (sysmiss(plb) | sysmiss(i_privacion))			 cuadrante=9.
RECODE cuadrantes (9=SYSMIS).
VARIABLE LABELS cuadrantes "Cuadrantes de Bienestar y Derechos sociales".
VALUE LABELS cuadrantes 
1 "Pobres"
2 "Vulnerables por carencias" 
3 "Vulnerables por ingresos"
4 "No pobres es y no vulnerables".
FORMATS cuadrantes (F1).

****************************************
*Profundidad en el espacio del bienestar
****************************************.
**********
FGT (a=1)
**********.

*Distancia normalizada del ingreso respecto a la lnea de bienestar.

IF rururb=1 & plb=1 prof_b1=(lp2_rur-ictpc)/(lp2_rur).
IF rururb=0 & plb=1 prof_b1= (lp2_urb-ictpc)/(lp2_urb).
IF plb=0                  prof_b1=0.
VARIABLE LABELS  prof_b1 "ndice FGT con alfa igual a 1 (lnea de bienestar)".

*Distancia normalizada del ingreso respecto a la lnea de bienestar mnimo.

IF rururb=1 & plb_m=1 prof_bm1=(lp1_rur-ictpc)/(lp1_rur).
IF rururb=0 & plb_m=1 prof_bm1= (lp1_urb-ictpc)/(lp1_urb).
IF plb_m=0                  prof_bm1=0.
VARIABLE LABELS  prof_bm1 "ndice FGT con alfa igual a 1 (lnea de bienestar mnimo)".


***********************************
*Profundidad de la privacin social
***********************************.

COMPUTE profun=(i_privacion/6).
VARIABLE LABELS profun "Profundidad de la privacin social".
FORMATS profun (F4.3).

***********************************
*Intensidad de la privacin social
***********************************.

*Poblacin pobre .

COMPUTE  int_pob=profun*pobreza.
VARIABLE LABELS int_pob "Intensidad de la privacin social: pobres ".

*Poblacin pobre  extrema.

COMPUTE int_pobe=profun*pobreza_e.
VARIABLE LABELS int_pobe "Intensidad de la privacin social: pobres extremos".

*Poblacin vulnerable por carencias.

COMPUTE int_vulcar=profun*vul_car.
VARIABLE LABELS int_vulcar "Intensidad de la privacin social: poblacion vulnerable por carencias".

*Poblacin carenciada.

COMPUTE int_caren=profun*carencias.
VARIABLE LABELS int_caren "Intensidad de la privacin social: poblacin carenciada".

SAVE OUTFILE='C:\Medicion\2010\SPSS\Bases\pobreza_10.sav'
 /KEEP = proyecto folioviv foliohog numren factor tam_loc rururb ent ubica_geo edad sexo
		ic_rezedu anac_e inas_esc niv_ed
		ic_asalud serv_sal
		ic_segsoc ss_dir pea par jef_ss cony_ss hijo_ss s_salud pam 
		ic_cv icv_pisos icv_muros icv_techos icv_hac
		ic_sbv isb_agua isb_dren isb_luz 
		ic_ali id_men tot_iaad tot_iamen ins_ali
		plb_m plb ictpc est_dis upm
		i_privacion pobreza pobreza_e pobreza_m  vul_car vul_ing no_pobv carencias carencias3 cuadrantes 
		prof_b1 prof_bm1 profun int_pob int_pobe int_vulcar int_caren
  /COMPRESSED.

*******************************
*
*	Concentrado estadstico
*	Nacional
*
*******************************

*Debido a la existencia de observaciones con valores faltantes, es necesario restringir los resultados
a la poblacin de la que se dispone de la informacin completa. Esta restriccin se incorpora en todos
los tabulados mediante la instruccin "if pobreza!=.".

SORT CASES by proyecto(A) folioviv (A) foliohog (A) numren(A).

COMPUTE valido=1.
IF (sysmiss(plb) or sysmiss(i_privacion)) valido=0.
fre valido.

SELECT IF valido=1.

WEIGHT BY factor.

**************************************
*Incidencia de las carencias sociales
**************************************.

MEANS TABLES= ic_rezedu ic_asalud ic_segsoc ic_cv ic_sbv ic_ali BY ent
  /CELLS MEAN.

**************************************************
*Poblacin con cada una de las carencias sociales
**************************************************.

MEANS TABLES= ic_rezedu ic_asalud ic_segsoc ic_cv ic_sbv ic_ali BY ent
  /CELLS SUM.

*******************************************************
*Incidencia en cada espacio y pobreza 
*******************************************************.

MEANS TABLES= plb plb_m carencias pobreza pobreza_e pobreza_m  BY ent
  /CELLS MEAN.

*****************************************************
*Poblacin en cada espacio y pobreza 
*****************************************************.

MEANS TABLES= plb plb_m carencias pobreza pobreza_e pobreza_m BY ent
  /CELLS SUM.









